@@ -28,7 +28,7 @@ class ServerAddressOutputMapping(template_def.OutputMapping):
         self.heat_output = self.public_ip_output_key
 
     def set_output(self, stack, cluster_template, cluster):
-        if not cluster_template.floating_ip_enabled:
+        if not cluster.floating_ip_enabled:
             self.heat_output = self.private_ip_output_key
 
         LOG.debug("Using heat_output: %s", self.heat_output)
@@ -124,7 +124,7 @@ class DcosCentosTemplateDefinition(template_def.BaseTemplateDefinition):
         # By default, master_discovery is set to 'static'
         # If --master-lb-enabled is specified,
         # master_discovery will be set to 'master_http_loadbalancer'
-        if cluster_template.master_lb_enabled:
+        if cluster.master_lb_enabled:
             extra_params['master_discovery'] = 'master_http_loadbalancer'
 
         if 'true' == extra_params['dcos_overlay_enable']:
@@ -156,8 +156,8 @@ class DcosCentosTemplateDefinition(template_def.BaseTemplateDefinition):
     def get_env_files(self, cluster_template, cluster):
         env_files = []
 
-        template_def.add_priv_net_env_file(env_files, cluster_template)
-        template_def.add_lb_env_file(env_files, cluster_template)
-        template_def.add_fip_env_file(env_files, cluster_template, cluster)
+        template_def.add_priv_net_env_file(env_files, cluster)
+        template_def.add_lb_env_file(env_files, cluster)
+        template_def.add_fip_env_file(env_files, cluster)
 
         return env_files
