@@ -13,11 +13,13 @@
 # under the License.
 
 from barbicanclient.v1 import client as barbicanclient
+from cinderclient.v2 import client as cinder_client
 from glanceclient import client as glanceclient
 from heatclient import client as heatclient
 from keystoneauth1.exceptions import catalog
 from neutronclient.v2_0 import client as neutronclient
 from novaclient import client as novaclient
+from octaviaclient.api.v2 import octavia
 from oslo_log import log as logging
 
 from magnum.common import exception
@@ -39,6 +41,8 @@ class OpenStackClients(object):
         self._barbican = None
         self._nova = None
         self._neutron = None
+        self._octavia = None
+        self._cinder = None
 
     def url_for(self, **kwargs):
         return self.keystone().session.get_endpoint(**kwargs)
@@ -80,6 +84,21 @@ class OpenStackClients(object):
     def _get_client_option(self, client, option):
         return getattr(getattr(CONF, '%s_client' % client), option)
 
+    @exception.wrap_keystone_exception
+    def octavia(self):
+        if self._octavia:
+            return self._octavia
+
+        region_name = self._get_client_option('octavia', 'region_name')
+        endpoint_type = self._get_client_option('octavia', 'endpoint_type')
+        endpoint = self.url_for(service_type='load-balancer',
+                                interface=endpoint_type,
+                                region_name=region_name)
+        session = self.keystone().session
+        return octavia.OctaviaAPI(session=session,
+                                  service_type='load-balancer',
+                                  endpoint=endpoint)
+
     @exception.wrap_keystone_exception
     def heat(self):
         if self._heat:
@@ -190,3 +209,24 @@ class OpenStackClients(object):
         }
         self._neutron = neutronclient.Client(**args)
         return self._neutron
+
+    @exception.wrap_keystone_exception
+    def cinder(self):
+        if self._cinder:
+            return self._cinder
+        endpoint_type = self._get_client_option('cinder', 'endpoint_type')
+        region_name = self._get_client_option('cinder', 'region_name')
+        cinderclient_version = self._get_client_option('cinder', 'api_version')
+        endpoint = self.url_for(service_type='block-storage',
+                                interface=endpoint_type,
+                                region_name=region_name)
+        args = {
+            'cacert': self._get_client_option('cinder', 'ca_file'),
+            'insecure': self._get_client_option('cinder', 'insecure')
+        }
+
+        session = self.keystone().session
+        self._cinder = cinder_client.Client(cinderclient_version,
+                                            session=session,
+                                            endpoint_override=endpoint, **args)
+        return self._cinder
