@@ -15,7 +15,6 @@
 """Common RPC service and API tools for Magnum."""
 
 import oslo_messaging as messaging
-from oslo_messaging.rpc import dispatcher
 from oslo_service import service
 from oslo_utils import importutils
 
@@ -47,23 +46,21 @@ class Service(service.Service):
     def __init__(self, topic, server, handlers, binary):
         super(Service, self).__init__()
         serializer = _init_serializer()
-        transport = messaging.get_rpc_transport(CONF)
         # TODO(asalkeld) add support for version='x.y'
-        access_policy = dispatcher.DefaultRPCAccessPolicy
         target = messaging.Target(topic=topic, server=server)
-        self._server = messaging.get_rpc_server(transport, target, handlers,
-                                                executor='eventlet',
-                                                serializer=serializer,
-                                                access_policy=access_policy)
+        self._server = rpc.get_server(target, handlers,
+                                      serializer=serializer)
+
         self.binary = binary
         profiler.setup(binary, CONF.host)
 
     def start(self):
-        # NOTE(suro-patz): The parent class has created a threadgroup, already
+        self._server.start()
+
+    def create_periodic_tasks(self):
         if CONF.periodic_enable:
             periodic.setup(CONF, self.tg)
         servicegroup.setup(CONF, self.binary, self.tg)
-        self._server.start()
 
     def stop(self):
         if self._server:
@@ -78,20 +75,16 @@ class Service(service.Service):
 
 
 class API(object):
-    def __init__(self, transport=None, context=None, topic=None, server=None,
+    def __init__(self, context=None, topic=None, server=None,
                  timeout=None):
         serializer = _init_serializer()
-        if transport is None:
-            exmods = rpc.get_allowed_exmods()
-            transport = messaging.get_rpc_transport(
-                CONF, allowed_remote_exmods=exmods)
         self._context = context
         if topic is None:
             topic = ''
         target = messaging.Target(topic=topic, server=server)
-        self._client = messaging.RPCClient(transport, target,
-                                           serializer=serializer,
-                                           timeout=timeout)
+        self._client = rpc.get_client(target,
+                                      serializer=serializer,
+                                      timeout=timeout)
 
     def _call(self, method, *args, **kwargs):
         return self._client.call(self._context, method, *args, **kwargs)
