@@ -10,15 +10,10 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from oslo_log import log as logging
-
 from magnum.conductor import k8s_api as k8s
 from magnum.conductor.scale_manager import ScaleManager
 
 
-LOG = logging.getLogger(__name__)
-
-
 class K8sScaleManager(ScaleManager):
 
     def __init__(self, context, osclient, cluster):
