@@ -1,10 +1,20 @@
-#!/bin/sh
-
 step="enable-prometheus-monitoring"
 printf "Starting to run ${step}\n"
 
 . /etc/sysconfig/heat-params
 
+if [ ! -z "$HTTP_PROXY" ]; then
+    export HTTP_PROXY
+fi
+
+if [ ! -z "$HTTPS_PROXY" ]; then
+    export HTTPS_PROXY
+fi
+
+if [ ! -z "$NO_PROXY" ]; then
+    export NO_PROXY
+fi
+
 function writeFile {
     # $1 is filename
     # $2 is file content
@@ -203,7 +213,7 @@ spec:
     protocol: TCP
     port: 9090
 ---
-apiVersion: extensions/v1beta1
+apiVersion: apps/v1
 kind: Deployment
 metadata:
   name: prometheus
@@ -313,13 +323,18 @@ spec:
   selector:
     grafana: "true"
 ---
-apiVersion: extensions/v1beta1
+apiVersion: apps/v1
 kind: Deployment
 metadata:
   name: grafana
   namespace: prometheus-monitoring
 spec:
   replicas: 1
+  selector:
+    matchLabels:
+      name: grafana
+      grafana: "true"
+      role: db
   template:
     metadata:
       labels:
@@ -333,7 +348,7 @@ spec:
           name: grafana
           env:
             - name: GF_SECURITY_ADMIN_PASSWORD
-              value: $ADMIN_PASSWD
+              value: ${GRAFANA_ADMIN_PASSWD}
             - name: GF_DASHBOARDS_JSON_ENABLED
               value: "true"
             - name: GF_DASHBOARDS_JSON_PATH
@@ -447,7 +462,7 @@ if [ "$(echo $PROMETHEUS_MONITORING | tr '[:upper:]' '[:lower:]')" = "true" ]; t
 
     # Write the binary for enable-monitoring
     KUBE_MON_BIN_CONTENT='''#!/bin/sh
-until  [ "ok" = "$(curl --silent http://127.0.0.1:8080/healthz)" ]
+until  [ "ok" = "$(kubectl get --raw='/healthz')" ]
 do
     echo "Waiting for Kubernetes API..."
     sleep 5
