@@ -106,6 +106,7 @@ class K8sFedoraTemplateDefinition(k8s_template_def.K8sTemplateDefinition):
                       'tiller_enabled',
                       'tiller_tag',
                       'tiller_namespace',
+                      'helm_client_url', 'helm_client_sha256',
                       'helm_client_tag',
                       'traefik_ingress_controller_tag',
                       'node_problem_detector_tag',
@@ -232,7 +233,7 @@ class K8sFedoraTemplateDefinition(k8s_template_def.K8sTemplateDefinition):
         template_def.add_etcd_volume_env_file(env_files, cluster)
         template_def.add_volume_env_file(env_files, cluster,
                                          nodegroup=nodegroup)
-        template_def.add_lb_env_file(env_files, cluster_template)
-        template_def.add_fip_env_file(env_files, cluster_template, cluster)
+        template_def.add_lb_env_file(env_files, cluster)
+        template_def.add_fip_env_file(env_files, cluster)
 
         return env_files
