@@ -19,6 +19,7 @@ from magnum.db import api as dbapi
 from magnum.objects import base
 from magnum.objects.cluster_template import ClusterTemplate
 from magnum.objects import fields as m_fields
+from magnum.objects.nodegroup import NodeGroup
 
 
 @base.MagnumObjectRegistry.register
@@ -47,8 +48,13 @@ class Cluster(base.MagnumPersistentObject, base.MagnumObject,
     # Version 1.16: Added 'master_flavor_id' field
     # Version 1.17: Added 'flavor_id' field
     # Version 1.18: Added 'health_status' and 'health_status_reason' field
+    # Version 1.19: Added nodegroups, default_ng_worker, default_ng_master
+    # Version 1.20: Fields node_count, master_count, node_addresses,
+    #               master_addresses are now properties.
+    # Version 1.21  Added fixed_network, fixed_subnet, floating_ip_enabled
+    # Version 1.22  Added master_lb_enabled
 
-    VERSION = '1.18'
+    VERSION = '1.22'
 
     dbapi = dbapi.get_instance()
 
@@ -71,11 +77,7 @@ class Cluster(base.MagnumPersistentObject, base.MagnumObject,
         'health_status_reason': fields.DictOfStringsField(nullable=True),
         'create_timeout': fields.IntegerField(nullable=True),
         'api_address': fields.StringField(nullable=True),
-        'node_addresses': fields.ListOfStringsField(nullable=True),
-        'node_count': fields.IntegerField(nullable=True),
-        'master_count': fields.IntegerField(nullable=True),
         'discovery_url': fields.StringField(nullable=True),
-        'master_addresses': fields.ListOfStringsField(nullable=True),
         'ca_cert_ref': fields.StringField(nullable=True),
         'magnum_cert_ref': fields.StringField(nullable=True),
         'cluster_template': fields.ObjectField('ClusterTemplate'),
@@ -84,7 +86,11 @@ class Cluster(base.MagnumPersistentObject, base.MagnumObject,
         'trustee_password': fields.StringField(nullable=True),
         'trustee_user_id': fields.StringField(nullable=True),
         'coe_version': fields.StringField(nullable=True),
-        'container_version': fields.StringField(nullable=True)
+        'container_version': fields.StringField(nullable=True),
+        'fixed_network': fields.StringField(nullable=True),
+        'fixed_subnet': fields.StringField(nullable=True),
+        'floating_ip_enabled': fields.BooleanField(default=True),
+        'master_lb_enabled': fields.BooleanField(default=False),
     }
 
     @staticmethod
@@ -104,6 +110,52 @@ class Cluster(base.MagnumPersistentObject, base.MagnumObject,
         cluster.obj_reset_changes()
         return cluster
 
+    @property
+    def nodegroups(self):
+        # Returns all nodegroups that belong to the cluster.
+        return NodeGroup.list(self._context, self.uuid)
+
+    @property
+    def default_ng_worker(self):
+        # Assume that every cluster will have only one default
+        # non-master nodegroup. We don't want to limit the roles
+        # so each nodegroup that does not have a master role is
+        # considered as a worker/minion nodegroup.
+        filters = {'is_default': True}
+        default_ngs = NodeGroup.list(self._context, self.uuid, filters=filters)
+        return [n for n in default_ngs if n.role != 'master'][0]
+
+    @property
+    def default_ng_master(self):
+        # Assume that every cluster will have only one default
+        # master nodegroup.
+        filters = {'role': 'master', 'is_default': True}
+        return NodeGroup.list(self._context, self.uuid, filters=filters)[0]
+
+    @property
+    def node_count(self):
+        return sum(n.node_count for n in self.nodegroups if n.role != 'master')
+
+    @property
+    def master_count(self):
+        return sum(n.node_count for n in self.nodegroups if n.role == 'master')
+
+    @property
+    def node_addresses(self):
+        node_addresses = []
+        for ng in self.nodegroups:
+            if ng.role != 'master':
+                node_addresses += ng.node_addresses
+        return node_addresses
+
+    @property
+    def master_addresses(self):
+        master_addresses = []
+        for ng in self.nodegroups:
+            if ng.role == 'master':
+                master_addresses += ng.node_addresses
+        return master_addresses
+
     @staticmethod
     def _from_db_object_list(db_objects, cls, context):
         """Converts a list of database entities to a list of formal objects."""
@@ -275,3 +327,15 @@ class Cluster(base.MagnumPersistentObject, base.MagnumObject,
         for field in self.fields:
             if self.obj_attr_is_set(field) and self[field] != current[field]:
                 self[field] = current[field]
+
+    def as_dict(self):
+        dict_ = super(Cluster, self).as_dict()
+        # Update the dict with the attributes coming form
+        # the cluster's nodegroups.
+        dict_.update({
+            'node_count': self.node_count,
+            'master_count': self.master_count,
+            'node_addresses': self.node_addresses,
+            'master_addresses': self.master_addresses
+        })
+        return dict_
