@@ -76,13 +76,16 @@ class ClusterUpdateJob(object):
         if self.cluster.status.endswith("_COMPLETE"):
             conductor_utils.notify_about_cluster_operation(
                 self.ctx, self.status_to_event[self.cluster.status],
-                taxonomy.OUTCOME_SUCCESS)
+                taxonomy.OUTCOME_SUCCESS, self.cluster)
         if self.cluster.status.endswith("_FAILED"):
             conductor_utils.notify_about_cluster_operation(
                 self.ctx, self.status_to_event[self.cluster.status],
-                taxonomy.OUTCOME_FAILURE)
+                taxonomy.OUTCOME_FAILURE, self.cluster)
         # if we're done with it, delete it
         if self.cluster.status == objects.fields.ClusterStatus.DELETE_COMPLETE:
+            # delete all the nodegroups that belong to this cluster
+            for ng in objects.NodeGroup.list(self.ctx, self.cluster.uuid):
+                ng.destroy()
             self.cluster.destroy()
         # end the "loop"
         raise loopingcall.LoopingCallDone()
@@ -149,7 +152,9 @@ class MagnumPeriodicTasks(periodic_task.PeriodicTasks):
         super(MagnumPeriodicTasks, self).__init__(conf)
         self.notifier = rpc.get_notifier()
 
-    @periodic_task.periodic_task(spacing=10, run_immediately=True)
+    @periodic_task.periodic_task(
+        spacing=CONF.kubernetes.health_polling_interval,
+        run_immediately=True)
     @set_context
     def sync_cluster_status(self, ctx):
         try:
