@@ -14,6 +14,7 @@ import datetime
 
 import mock
 from oslo_config import cfg
+from oslo_serialization import jsonutils
 from oslo_utils import timeutils
 from oslo_utils import uuidutils
 from wsme import types as wtypes
@@ -27,6 +28,7 @@ from magnum import objects
 from magnum.tests import base
 from magnum.tests.unit.api import base as api_base
 from magnum.tests.unit.api import utils as apiutils
+from magnum.tests.unit.db import utils as db_utils
 from magnum.tests.unit.objects import utils as obj_utils
 
 CONF = magnum.conf.CONF
@@ -116,9 +118,27 @@ class TestListCluster(api_base.FunctionalTest):
     def test_get_one_by_uuid(self):
         temp_uuid = uuidutils.generate_uuid()
         obj_utils.create_test_cluster(self.context, uuid=temp_uuid)
-        response = self.get_json(
-            '/clusters/%s' % temp_uuid)
+        response = self.get_json('/clusters/%s' % temp_uuid)
         self.assertEqual(temp_uuid, response['uuid'])
+        self.assertIn('labels_overridden', response)
+        self.assertIn('labels_added', response)
+        self.assertIn('labels_skipped', response)
+
+    def test_get_one_merged_labels(self):
+        ct_uuid = uuidutils.generate_uuid()
+        ct_labels = {'label1': 'value1', 'label2': 'value2'}
+        obj_utils.create_test_cluster_template(self.context, uuid=ct_uuid,
+                                               labels=ct_labels)
+        c_uuid = uuidutils.generate_uuid()
+        c_labels = {'label1': 'value3', 'label4': 'value4'}
+        obj_utils.create_test_cluster(self.context, uuid=c_uuid,
+                                      labels=c_labels,
+                                      cluster_template_id=ct_uuid)
+        response = self.get_json('/clusters/%s' % c_uuid)
+        self.assertEqual(c_labels, response['labels'])
+        self.assertEqual({'label1': 'value1'}, response['labels_overridden'])
+        self.assertEqual({'label2': 'value2'}, response['labels_skipped'])
+        self.assertEqual({'label4': 'value4'}, response['labels_added'])
 
     def test_get_one_by_uuid_not_found(self):
         temp_uuid = uuidutils.generate_uuid()
@@ -269,6 +289,8 @@ class TestPatch(api_base.FunctionalTest):
     def _sim_rpc_cluster_update(self, cluster, node_count, health_status,
                                 health_status_reason, rollback=False):
         cluster.status = 'UPDATE_IN_PROGRESS'
+        cluster.health_status = health_status
+        cluster.health_status_reason = health_status_reason
         default_ng_worker = cluster.default_ng_worker
         default_ng_worker.node_count = node_count
         default_ng_worker.save()
@@ -298,6 +320,42 @@ class TestPatch(api_base.FunctionalTest):
         self.assertEqual(self.cluster_obj.cluster_template_id,
                          response['cluster_template_id'])
 
+    @mock.patch('oslo_utils.timeutils.utcnow')
+    def test_replace_health_status_ok(self, mock_utcnow):
+        new_health_status = 'HEALTHY'
+        new_health_status_reason = {'api': 'ok'}
+        health_status_reason_dumps = jsonutils.dumps(new_health_status_reason)
+        test_time = datetime.datetime(2000, 1, 1, 0, 0)
+        mock_utcnow.return_value = test_time
+        old_node_count = self.cluster_obj.default_ng_worker.node_count
+        db_utils.create_test_nodegroup(cluster_id=self.cluster_obj.uuid,
+                                       name='non_default_ng')
+        response = self.patch_json('/clusters/%s' % self.cluster_obj.uuid,
+                                   [{'path': '/health_status',
+                                     'value': new_health_status,
+                                     'op': 'replace'},
+                                    {'path': '/health_status_reason',
+                                     'value': health_status_reason_dumps,
+                                     'op': 'replace'}])
+        self.assertEqual('application/json', response.content_type)
+        self.assertEqual(202, response.status_code)
+
+        response = self.get_json('/clusters/%s' % self.cluster_obj.uuid)
+        self.assertEqual(new_health_status, response['health_status'])
+        self.assertEqual(new_health_status_reason,
+                         response['health_status_reason'])
+
+        new_node_count = self.cluster_obj.default_ng_worker.node_count
+        self.assertEqual(old_node_count, new_node_count)
+
+        return_updated_at = timeutils.parse_isotime(
+            response['updated_at']).replace(tzinfo=None)
+        self.assertEqual(test_time, return_updated_at)
+        # Assert nothing else was changed
+        self.assertEqual(self.cluster_obj.uuid, response['uuid'])
+        self.assertEqual(self.cluster_obj.cluster_template_id,
+                         response['cluster_template_id'])
+
     @mock.patch('oslo_utils.timeutils.utcnow')
     def test_replace_ok_by_name(self, mock_utcnow):
         new_node_count = 4
@@ -787,7 +845,8 @@ class TestPost(api_base.FunctionalTest):
         cluster_template = obj_utils.create_test_cluster_template(
             self.context, name='foo', uuid='foo', master_lb_enabled=False)
         bdict = apiutils.cluster_post_data(
-            cluster_template_id=cluster_template.name, master_count=3)
+            cluster_template_id=cluster_template.name, master_count=3,
+            master_lb_enabled=False)
         response = self.post_json('/clusters', bdict, expect_errors=True)
         self.assertEqual('application/json', response.content_type)
         self.assertEqual(400, response.status_int)
@@ -911,6 +970,42 @@ class TestPost(api_base.FunctionalTest):
         # Verify flavor_id from ClusterTemplate is used
         self.assertEqual('m1.small', cluster[0].flavor_id)
 
+    def test_create_cluster_without_merge_labels(self):
+        self.cluster_template.labels = {'label1': 'value1', 'label2': 'value2'}
+        self.cluster_template.save()
+        cluster_labels = {'label2': 'value3', 'label4': 'value4'}
+        bdict = apiutils.cluster_post_data(labels=cluster_labels)
+        response = self.post_json('/clusters', bdict)
+        self.assertEqual('application/json', response.content_type)
+        self.assertEqual(202, response.status_int)
+        cluster, timeout = self.mock_cluster_create.call_args
+        self.assertEqual(cluster_labels, cluster[0].labels)
+
+    def test_create_cluster_with_merge_labels(self):
+        self.cluster_template.labels = {'label1': 'value1', 'label2': 'value2'}
+        self.cluster_template.save()
+        cluster_labels = {'label2': 'value3', 'label4': 'value4'}
+        bdict = apiutils.cluster_post_data(labels=cluster_labels,
+                                           merge_labels=True)
+        response = self.post_json('/clusters', bdict)
+        self.assertEqual('application/json', response.content_type)
+        self.assertEqual(202, response.status_int)
+        cluster, timeout = self.mock_cluster_create.call_args
+        expected = self.cluster_template.labels
+        expected.update(cluster_labels)
+        self.assertEqual(expected, cluster[0].labels)
+
+    def test_create_cluster_with_merge_labels_no_labels(self):
+        self.cluster_template.labels = {'label1': 'value1', 'label2': 'value2'}
+        self.cluster_template.save()
+        bdict = apiutils.cluster_post_data(merge_labels=True)
+        del bdict['labels']
+        response = self.post_json('/clusters', bdict)
+        self.assertEqual('application/json', response.content_type)
+        self.assertEqual(202, response.status_int)
+        cluster, timeout = self.mock_cluster_create.call_args
+        self.assertEqual(self.cluster_template.labels, cluster[0].labels)
+
 
 class TestDelete(api_base.FunctionalTest):
     def setUp(self):
