@@ -27,6 +27,7 @@ from magnum.conductor.handlers import cluster_conductor
 import magnum.conf
 from magnum.drivers.k8s_fedora_atomic_v1 import driver as k8s_atomic_dr
 from magnum import objects
+from magnum.objects.fields import ClusterHealthStatus
 from magnum.objects.fields import ClusterStatus as cluster_status
 from magnum.tests import fake_notifier
 from magnum.tests.unit.db import base as db_base
@@ -79,7 +80,8 @@ class TestHandler(db_base.DbTestCase):
         self.master.create()
         self.worker.create()
         self.cluster.status = cluster_status.CREATE_COMPLETE
-        self.handler.cluster_update(self.context, self.cluster, node_count)
+        self.handler.cluster_update(self.context, self.cluster, node_count,
+                                    ClusterHealthStatus.UNKNOWN, {})
 
         notifications = fake_notifier.NOTIFICATIONS
         self.assertEqual(1, len(notifications))
@@ -111,7 +113,8 @@ class TestHandler(db_base.DbTestCase):
         self.worker.create()
         self.cluster.status = cluster_status.CREATE_FAILED
         self.assertRaises(exception.NotSupported, self.handler.cluster_update,
-                          self.context, self.cluster, node_count)
+                          self.context, self.cluster, node_count,
+                          ClusterHealthStatus.UNKNOWN, {})
 
         notifications = fake_notifier.NOTIFICATIONS
         self.assertEqual(1, len(notifications))
@@ -144,7 +147,8 @@ class TestHandler(db_base.DbTestCase):
         self.cluster.status = cluster_status.CREATE_COMPLETE
         self.master.create()
         self.worker.create()
-        self.handler.cluster_update(self.context, self.cluster, node_count)
+        self.handler.cluster_update(self.context, self.cluster, node_count,
+                                    ClusterHealthStatus.UNKNOWN, {})
 
         notifications = fake_notifier.NOTIFICATIONS
         self.assertEqual(1, len(notifications))
@@ -470,7 +474,8 @@ class TestHandler(db_base.DbTestCase):
                                     timeout)
 
         mock_extract_tmpl_def.assert_called_once_with(self.context,
-                                                      cluster)
+                                                      cluster,
+                                                      nodegroups=None)
         mock_get_template_contents.assert_called_once_with(
             'the/template/path.yaml')
         mock_process_mult.assert_called_once_with(
@@ -487,7 +492,8 @@ class TestHandler(db_base.DbTestCase):
                 'file:///the/template/env_file_2':
                     'content of file:///the/template/env_file_2'
             },
-            parameters={'heat_param_1': 'foo', 'heat_param_2': 'bar'},
+            parameters={'is_cluster_stack': True, 'heat_param_1': 'foo',
+                        'heat_param_2': 'bar'},
             stack_name=('%s-short_id' % cluster.name),
             template='some template yaml',
             timeout_mins=timeout)
@@ -543,6 +549,8 @@ class TestHandler(db_base.DbTestCase):
         osc = mock.MagicMock()
         mock_openstack_client_class.return_value = osc
         osc.heat.side_effect = exc.HTTPConflict
+        self.worker.create()
+        self.master.create()
         self.assertRaises(exception.OperationInProgress,
                           self.handler.cluster_delete,
                           self.context,
@@ -570,6 +578,8 @@ class TestHandler(db_base.DbTestCase):
         mock_octavia.return_value = True
         mock_driver.return_value = k8s_atomic_dr.Driver()
 
+        self.master.create()
+        self.worker.create()
         self.handler.cluster_delete(self.context, self.cluster.uuid)
 
         notifications = fake_notifier.NOTIFICATIONS
