@@ -44,11 +44,10 @@ class TestClusterConductorWithK8s(base.TestCase):
             'dns_nameserver': 'dns_nameserver',
             'external_network_id': 'e2a6c8b0-a3c2-42a3-b3f4-01400a30896e',
             'fixed_network': 'fixed_network',
-            'fixed_subnet': 'fixed_subnet',
+            'fixed_subnet': 'c2a6c8b0-a3c2-42a3-b3f4-01400a30896f',
             'network_driver': 'network_driver',
             'volume_driver': 'volume_driver',
             'docker_volume_size': 20,
-            'master_flavor_id': 'flavor_id',
             'docker_storage_driver': 'devicemapper',
             'cluster_distro': 'fedora-atomic',
             'coe': 'kubernetes',
@@ -121,8 +120,9 @@ class TestClusterConductorWithK8s(base.TestCase):
             'project_id': 'project_id',
             'keystone_auth_default_policy': self.keystone_auth_default_policy,
             'fixed_network': 'fixed_network',
-            'fixed_subnet': 'fixed_subnet',
+            'fixed_subnet': 'c2a6c8b0-a3c2-42a3-b3f4-01400a30896f',
             'floating_ip_enabled': False,
+            'master_lb_enabled': False,
         }
         self.worker_ng_dict = {
             'uuid': '5d12f6fd-a196-4bf0-ae4c-1f639a523a53',
@@ -162,6 +162,13 @@ class TestClusterConductorWithK8s(base.TestCase):
         self.mock_osc_class = osc_patcher.start()
         self.addCleanup(osc_patcher.stop)
         self.mock_osc = mock.MagicMock()
+
+        mock_keypair = mock.MagicMock()
+        mock_keypair.public_key = 'ssh-rsa AAAAB3Nz'
+        self.mock_nova = mock.MagicMock()
+        self.mock_nova.keypairs.get.return_value = mock_keypair
+        self.mock_osc.nova.return_value = self.mock_nova
+
         self.mock_osc.url_for.return_value = 'http://192.168.10.10:5000/v3'
         self.mock_osc.magnum_url.return_value = 'http://127.0.0.1:9511/v1'
         self.mock_osc.cinder_region_name.return_value = 'RegionOne'
@@ -180,7 +187,9 @@ class TestClusterConductorWithK8s(base.TestCase):
                           'lvmdriver-1', group='cinder')
         CONF.set_override('default_etcd_volume_type',
                           'lvmdriver-1', group='cinder')
+        self.fixed_subnet_cidr = '20.200.0.0/16'
 
+    @patch('magnum.common.neutron.get_subnet')
     @patch('requests.get')
     @patch('magnum.objects.ClusterTemplate.get_by_uuid')
     @patch('magnum.objects.NodeGroup.list')
@@ -195,11 +204,12 @@ class TestClusterConductorWithK8s(base.TestCase):
             mock_driver,
             mock_objects_nodegroup_list,
             mock_objects_cluster_template_get_by_uuid,
-            mock_get):
+            mock_get,
+            mock_get_subnet):
         self._test_extract_template_definition(
             mock_generate_csr_and_key, mock_sign_node_certificate,
             mock_driver, mock_objects_cluster_template_get_by_uuid, mock_get,
-            mock_objects_nodegroup_list)
+            mock_objects_nodegroup_list, mock_get_subnet)
 
     def _test_extract_template_definition(
             self,
@@ -209,15 +219,15 @@ class TestClusterConductorWithK8s(base.TestCase):
             mock_objects_cluster_template_get_by_uuid,
             mock_get,
             mock_objects_nodegroup_list,
+            mock_get_subnet,
             missing_attr=None):
         if missing_attr in self.cluster_template_dict:
             self.cluster_template_dict[missing_attr] = None
         elif missing_attr in self.cluster_dict:
             self.cluster_dict[missing_attr] = None
-        elif missing_attr == 'node_count':
-            self.worker_ng_dict['node_count'] = None
-        elif missing_attr == 'master_count':
-            self.master_ng_dict['node_count'] = None
+        if missing_attr == 'image_id':
+            del self.worker_ng_dict['image_id']
+            del self.master_ng_dict['image_id']
         cluster_template = objects.ClusterTemplate(
             self.context, **self.cluster_template_dict)
         mock_generate_csr_and_key.return_value = {'csr': 'csr',
@@ -238,6 +248,8 @@ class TestClusterConductorWithK8s(base.TestCase):
         mock_objects_nodegroup_list.return_value = [master_ng, worker_ng]
         mock_driver.return_value = k8s_dr.Driver()
 
+        mock_get_subnet.return_value = self.fixed_subnet_cidr
+
         (template_path,
          definition,
          env_files) = mock_driver()._extract_template_definition(self.context,
@@ -245,7 +257,6 @@ class TestClusterConductorWithK8s(base.TestCase):
 
         mapping = {
             'dns_nameserver': 'dns_nameserver',
-            'image_id': 'server_image',
             'flavor_id': 'minion_flavor',
             'docker_volume_size': 'docker_volume_size',
             'docker_storage_driver': 'docker_storage_driver',
@@ -268,8 +279,8 @@ class TestClusterConductorWithK8s(base.TestCase):
                        'influx_grafana_dashboard_enabled': 'True',
                        'docker_volume_type': 'lvmdriver-1',
                        'boot_volume_type': 'lvmdriver-1',
-                       'etcd_volume_type': 'lvmdriver-1',
                        'etcd_volume_size': None,
+                       'etcd_volume_type': '',
                        'availability_zone': 'az_1',
                        'cert_manager_api': 'False',
                        'ingress_controller': 'i-controller',
@@ -288,6 +299,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'magnum_url': self.mock_osc.magnum_url.return_value,
             'tls_disabled': False,
             'insecure_registry': '10.0.0.1:5000',
+            'image_id': ['master_image', 'minion_image']
         }
         expected = {
             'cloud_provider_enabled': 'false',
@@ -295,11 +307,12 @@ class TestClusterConductorWithK8s(base.TestCase):
             'external_network': 'e2a6c8b0-a3c2-42a3-b3f4-01400a30896e',
             'fixed_network': 'fixed_network',
             'fixed_network_name': 'fixed_network',
-            'fixed_subnet': 'fixed_subnet',
+            'fixed_subnet': 'c2a6c8b0-a3c2-42a3-b3f4-01400a30896f',
             'network_driver': 'network_driver',
             'volume_driver': 'volume_driver',
             'dns_nameserver': 'dns_nameserver',
-            'server_image': 'image_id',
+            'master_image': 'image_id',
+            'minion_image': 'image_id',
             'minion_flavor': 'flavor_id',
             'master_flavor': 'master_flavor_id',
             'number_of_minions': 1,
@@ -309,6 +322,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'docker_storage_driver': 'devicemapper',
             'discovery_url': 'https://discovery.etcd.io/test',
             'etcd_volume_size': None,
+            'etcd_volume_type': '',
             'flannel_network_cidr': '10.101.0.0/16',
             'flannel_network_subnetlen': '26',
             'flannel_backend': 'vxlan',
@@ -321,7 +335,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'influx_grafana_dashboard_enabled': 'True',
             'http_proxy': 'http_proxy',
             'https_proxy': 'https_proxy',
-            'no_proxy': 'no_proxy',
+            'no_proxy': 'no_proxy,20.200.0.0/16',
             'username': 'fake_user',
             'cluster_uuid': self.cluster_dict['uuid'],
             'magnum_url': self.mock_osc.magnum_url.return_value,
@@ -338,6 +352,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'kube_version': 'fake-version',
             'verify_ca': True,
             'openstack_ca': '',
+            'ssh_public_key': 'ssh-rsa AAAAB3Nz',
             "nodes_affinity_policy": "soft-anti-affinity",
             'availability_zone': 'az_1',
             'cert_manager_api': 'False',
@@ -360,18 +375,25 @@ class TestClusterConductorWithK8s(base.TestCase):
             'keystone_auth_default_policy': self.keystone_auth_default_policy,
             'boot_volume_size': '60',
             'boot_volume_type': 'lvmdriver-1',
-            'etcd_volume_type': 'lvmdriver-1'
+            'master_role': 'master',
+            'worker_role': 'worker',
+            'master_nodegroup_name': 'master_ng',
+            'worker_nodegroup_name': 'worker_ng',
+            'post_install_manifest_url': '',
+            'master_lb_allowed_cidrs': None,
+            'fixed_subnet_cidr': self.fixed_subnet_cidr,
         }
+
         if missing_attr is not None:
-            expected.pop(mapping[missing_attr], None)
+            attrs = mapping[missing_attr]
+            if not isinstance(attrs, list):
+                attrs = [attrs]
+            for attr in attrs:
+                expected.pop(attr, None)
 
         if missing_attr == 'node_count':
             expected['max_node_count'] = None
 
-        if missing_attr == 'image_id':
-            expected['master_image'] = None
-            expected['minion_image'] = None
-
         self.assertEqual(expected, definition)
         self.assertEqual(
             ['../../common/templates/environments/no_private_network.yaml',
@@ -383,6 +405,7 @@ class TestClusterConductorWithK8s(base.TestCase):
              ],
             env_files)
 
+    @patch('magnum.common.neutron.get_subnet')
     @patch('requests.get')
     @patch('magnum.objects.ClusterTemplate.get_by_uuid')
     @patch('magnum.objects.NodeGroup.list')
@@ -397,7 +420,8 @@ class TestClusterConductorWithK8s(base.TestCase):
             mock_driver,
             mock_objects_nodegroup_list,
             mock_objects_cluster_template_get_by_uuid,
-            mock_get):
+            mock_get,
+            mock_get_subnet):
         self.cluster_template_dict['registry_enabled'] = True
         cluster_template = objects.ClusterTemplate(
             self.context, **self.cluster_template_dict)
@@ -417,6 +441,7 @@ class TestClusterConductorWithK8s(base.TestCase):
         master_ng = objects.NodeGroup(self.context, **self.master_ng_dict)
         mock_objects_nodegroup_list.return_value = [master_ng, worker_ng]
         mock_driver.return_value = k8s_dr.Driver()
+        mock_get_subnet.return_value = self.fixed_subnet_cidr
 
         CONF.set_override('swift_region',
                           'RegionOne',
@@ -441,10 +466,11 @@ class TestClusterConductorWithK8s(base.TestCase):
             'docker_volume_size': 20,
             'docker_volume_type': 'lvmdriver-1',
             'etcd_volume_size': None,
+            'etcd_volume_type': '',
             'external_network': 'e2a6c8b0-a3c2-42a3-b3f4-01400a30896e',
             'fixed_network': 'fixed_network',
             'fixed_network_name': 'fixed_network',
-            'fixed_subnet': 'fixed_subnet',
+            'fixed_subnet': 'c2a6c8b0-a3c2-42a3-b3f4-01400a30896f',
             'flannel_backend': 'vxlan',
             'flannel_network_cidr': '10.101.0.0/16',
             'flannel_network_subnetlen': '26',
@@ -461,13 +487,14 @@ class TestClusterConductorWithK8s(base.TestCase):
             'master_flavor': 'master_flavor_id',
             'minion_flavor': 'flavor_id',
             'network_driver': 'network_driver',
-            'no_proxy': 'no_proxy',
+            'no_proxy': 'no_proxy,20.200.0.0/16',
             'number_of_masters': 1,
             'number_of_minions': 1,
             'region_name': 'RegionOne',
             'registry_container': 'docker_registry',
             'registry_enabled': True,
-            'server_image': 'image_id',
+            'master_image': 'image_id',
+            'minion_image': 'image_id',
             'ssh_key_name': 'keypair_id',
             'swift_region': 'RegionOne',
             'tls_disabled': False,
@@ -482,6 +509,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'kube_version': 'fake-version',
             'verify_ca': True,
             'openstack_ca': '',
+            'ssh_public_key': 'ssh-rsa AAAAB3Nz',
             "nodes_affinity_policy": "soft-anti-affinity",
             'availability_zone': 'az_1',
             'cert_manager_api': 'False',
@@ -504,7 +532,13 @@ class TestClusterConductorWithK8s(base.TestCase):
             'keystone_auth_default_policy': self.keystone_auth_default_policy,
             'boot_volume_size': '60',
             'boot_volume_type': 'lvmdriver-1',
-            'etcd_volume_type': 'lvmdriver-1'
+            'master_role': 'master',
+            'worker_role': 'worker',
+            'master_nodegroup_name': 'master_ng',
+            'worker_nodegroup_name': 'worker_ng',
+            'post_install_manifest_url': '',
+            'master_lb_allowed_cidrs': None,
+            'fixed_subnet_cidr': self.fixed_subnet_cidr
         }
 
         self.assertEqual(expected, definition)
@@ -518,6 +552,7 @@ class TestClusterConductorWithK8s(base.TestCase):
              ],
             env_files)
 
+    @patch('magnum.common.neutron.get_subnet')
     @patch('requests.get')
     @patch('magnum.objects.ClusterTemplate.get_by_uuid')
     @patch('magnum.objects.NodeGroup.list')
@@ -532,7 +567,8 @@ class TestClusterConductorWithK8s(base.TestCase):
             mock_driver,
             mock_objects_nodegroup_list,
             mock_objects_cluster_template_get_by_uuid,
-            mock_get):
+            mock_get,
+            mock_get_subnet):
 
         not_required = ['image_id', 'flavor_id', 'dns_nameserver',
                         'docker_volume_size', 'http_proxy',
@@ -558,9 +594,13 @@ class TestClusterConductorWithK8s(base.TestCase):
         mock_get.return_value = mock_resp
         mock_driver.return_value = k8s_dr.Driver()
         cluster = objects.Cluster(self.context, **self.cluster_dict)
+        del self.worker_ng_dict['image_id']
         worker_ng = objects.NodeGroup(self.context, **self.worker_ng_dict)
+        del self.master_ng_dict['image_id']
         master_ng = objects.NodeGroup(self.context, **self.master_ng_dict)
+        master_ng.image_id = None
         mock_objects_nodegroup_list.return_value = [master_ng, worker_ng]
+        mock_get_subnet.return_value = self.fixed_subnet_cidr
 
         (template_path,
          definition,
@@ -573,11 +613,12 @@ class TestClusterConductorWithK8s(base.TestCase):
             'cluster_uuid': '5d12f6fd-a196-4bf0-ae4c-1f639a523a52',
             'discovery_url': 'https://discovery.etcd.io/test',
             'docker_volume_size': 20,
+            'docker_volume_type': 'lvmdriver-1',
             'master_flavor': 'master_flavor_id',
             'minion_flavor': 'flavor_id',
             'fixed_network': 'fixed_network',
             'fixed_network_name': 'fixed_network',
-            'fixed_subnet': 'fixed_subnet',
+            'fixed_subnet': 'c2a6c8b0-a3c2-42a3-b3f4-01400a30896f',
             'external_network': 'e2a6c8b0-a3c2-42a3-b3f4-01400a30896e',
             'flannel_backend': 'vxlan',
             'flannel_network_cidr': '10.101.0.0/16',
@@ -589,8 +630,8 @@ class TestClusterConductorWithK8s(base.TestCase):
             'grafana_admin_passwd': 'fake_pwd',
             'kube_dashboard_enabled': 'True',
             'influx_grafana_dashboard_enabled': 'True',
-            'docker_volume_type': 'lvmdriver-1',
             'etcd_volume_size': None,
+            'etcd_volume_type': '',
             'insecure_registry_url': '10.0.0.1:5000',
             'kube_version': 'fake-version',
             'magnum_url': 'http://127.0.0.1:9511/v1',
@@ -608,6 +649,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'username': 'fake_user',
             'verify_ca': True,
             'openstack_ca': '',
+            'ssh_public_key': 'ssh-rsa AAAAB3Nz',
             "nodes_affinity_policy": "soft-anti-affinity",
             'availability_zone': 'az_1',
             'cert_manager_api': 'False',
@@ -625,12 +667,16 @@ class TestClusterConductorWithK8s(base.TestCase):
             'portal_network_cidr': '10.254.0.0/16',
             'project_id': 'project_id',
             'max_node_count': 2,
-            'master_image': None,
-            'minion_image': None,
-            'keystone_auth_default_policy': self.keystone_auth_default_policy,
             'boot_volume_size': '60',
             'boot_volume_type': 'lvmdriver-1',
-            'etcd_volume_type': 'lvmdriver-1'
+            'keystone_auth_default_policy': self.keystone_auth_default_policy,
+            'master_role': 'master',
+            'worker_role': 'worker',
+            'master_nodegroup_name': 'master_ng',
+            'worker_nodegroup_name': 'worker_ng',
+            'post_install_manifest_url': '',
+            'master_lb_allowed_cidrs': None,
+            'fixed_subnet_cidr': self.fixed_subnet_cidr
         }
         self.assertEqual(expected, definition)
         self.assertEqual(
@@ -643,6 +689,7 @@ class TestClusterConductorWithK8s(base.TestCase):
              ],
             env_files)
 
+    @patch('magnum.common.neutron.get_subnet')
     @patch('requests.get')
     @patch('magnum.objects.ClusterTemplate.get_by_uuid')
     @patch('magnum.objects.NodeGroup.list')
@@ -652,7 +699,8 @@ class TestClusterConductorWithK8s(base.TestCase):
             mock_driver,
             mock_objects_nodegroup_list,
             mock_objects_cluster_template_get_by_uuid,
-            mock_get):
+            mock_get,
+            mock_get_subnet):
         self.cluster_template_dict['cluster_distro'] = 'coreos'
         cluster_template = objects.ClusterTemplate(
             self.context, **self.cluster_template_dict)
@@ -669,6 +717,7 @@ class TestClusterConductorWithK8s(base.TestCase):
         master_ng = objects.NodeGroup(self.context, **self.master_ng_dict)
         mock_objects_nodegroup_list.return_value = [master_ng, worker_ng]
         mock_driver.return_value = k8s_coreos_dr.Driver()
+        mock_get_subnet.return_value = self.fixed_subnet_cidr
 
         (template_path,
          definition,
@@ -680,16 +729,17 @@ class TestClusterConductorWithK8s(base.TestCase):
             'external_network': 'e2a6c8b0-a3c2-42a3-b3f4-01400a30896e',
             'fixed_network': 'fixed_network',
             'fixed_network_name': 'fixed_network',
-            'fixed_subnet': 'fixed_subnet',
+            'fixed_subnet': 'c2a6c8b0-a3c2-42a3-b3f4-01400a30896f',
             'availability_zone': 'az_1',
             'nodes_affinity_policy': 'soft-anti-affinity',
             'dns_nameserver': 'dns_nameserver',
             'docker_storage_driver': 'devicemapper',
             'docker_volume_size': 20,
             'docker_volume_type': 'lvmdriver-1',
-            'server_image': 'image_id',
             'minion_flavor': 'flavor_id',
             'master_flavor': 'master_flavor_id',
+            'master_image': 'image_id',
+            'minion_image': 'image_id',
             'number_of_minions': 1,
             'number_of_masters': 1,
             'network_driver': 'network_driver',
@@ -698,7 +748,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'etcd_volume_size': None,
             'http_proxy': 'http_proxy',
             'https_proxy': 'https_proxy',
-            'no_proxy': 'no_proxy',
+            'no_proxy': 'no_proxy,20.200.0.0/16',
             'flannel_network_cidr': '10.101.0.0/16',
             'flannel_network_subnetlen': '26',
             'flannel_backend': 'vxlan',
@@ -725,6 +775,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'kube_version': 'fake-version',
             'verify_ca': True,
             'openstack_ca': '',
+            'ssh_public_key': 'ssh-rsa AAAAB3Nz',
             'openstack_ca_coreos': '',
             'cert_manager_api': 'False',
             'ingress_controller': 'i-controller',
@@ -737,6 +788,12 @@ class TestClusterConductorWithK8s(base.TestCase):
             'kubeproxy_options': '--kubeproxy',
             'octavia_enabled': False,
             'portal_network_cidr': '10.254.0.0/16',
+            'master_role': 'master',
+            'worker_role': 'worker',
+            'master_nodegroup_name': 'master_ng',
+            'worker_nodegroup_name': 'worker_ng',
+            'master_lb_allowed_cidrs': None,
+            'fixed_subnet_cidr': self.fixed_subnet_cidr,
         }
         self.assertEqual(expected, definition)
         self.assertEqual(
@@ -749,6 +806,7 @@ class TestClusterConductorWithK8s(base.TestCase):
              ],
             env_files)
 
+    @patch('magnum.common.neutron.get_subnet')
     @patch('requests.get')
     @patch('magnum.objects.ClusterTemplate.get_by_uuid')
     @patch('magnum.objects.NodeGroup.list')
@@ -758,7 +816,8 @@ class TestClusterConductorWithK8s(base.TestCase):
             mock_driver,
             mock_objects_nodegroup_list,
             mock_objects_cluster_template_get_by_uuid,
-            reqget):
+            reqget,
+            mock_get_subnet):
         self.cluster_template_dict['cluster_distro'] = 'coreos'
         self.cluster_dict['discovery_url'] = None
         mock_req = mock.MagicMock(text='http://tokentest/h1/h2/h3',
@@ -773,6 +832,7 @@ class TestClusterConductorWithK8s(base.TestCase):
         master_ng = objects.NodeGroup(self.context, **self.master_ng_dict)
         mock_objects_nodegroup_list.return_value = [master_ng, worker_ng]
         mock_driver.return_value = k8s_coreos_dr.Driver()
+        mock_get_subnet.return_value = self.fixed_subnet_cidr
 
         (template_path,
          definition,
@@ -785,12 +845,13 @@ class TestClusterConductorWithK8s(base.TestCase):
             'external_network': 'e2a6c8b0-a3c2-42a3-b3f4-01400a30896e',
             'fixed_network': 'fixed_network',
             'fixed_network_name': 'fixed_network',
-            'fixed_subnet': 'fixed_subnet',
+            'fixed_subnet': 'c2a6c8b0-a3c2-42a3-b3f4-01400a30896f',
             'dns_nameserver': 'dns_nameserver',
             'docker_storage_driver': u'devicemapper',
             'docker_volume_size': 20,
             'docker_volume_type': u'lvmdriver-1',
-            'server_image': 'image_id',
+            'master_image': 'image_id',
+            'minion_image': 'image_id',
             'minion_flavor': 'flavor_id',
             'master_flavor': 'master_flavor_id',
             'number_of_minions': 1,
@@ -801,7 +862,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'etcd_volume_size': None,
             'http_proxy': 'http_proxy',
             'https_proxy': 'https_proxy',
-            'no_proxy': 'no_proxy',
+            'no_proxy': 'no_proxy,20.200.0.0/16',
             'nodes_affinity_policy': 'soft-anti-affinity',
             'flannel_network_cidr': '10.101.0.0/16',
             'flannel_network_subnetlen': '26',
@@ -829,6 +890,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'kube_version': 'fake-version',
             'verify_ca': True,
             'openstack_ca': '',
+            'ssh_public_key': 'ssh-rsa AAAAB3Nz',
             'openstack_ca_coreos': '',
             'cert_manager_api': 'False',
             'ingress_controller': 'i-controller',
@@ -841,6 +903,12 @@ class TestClusterConductorWithK8s(base.TestCase):
             'kubeproxy_options': '--kubeproxy',
             'octavia_enabled': False,
             'portal_network_cidr': '10.254.0.0/16',
+            'master_role': 'master',
+            'worker_role': 'worker',
+            'master_nodegroup_name': 'master_ng',
+            'worker_nodegroup_name': 'worker_ng',
+            'master_lb_allowed_cidrs': None,
+            'fixed_subnet_cidr': self.fixed_subnet_cidr,
         }
         self.assertEqual(expected, definition)
         self.assertEqual(
@@ -853,6 +921,7 @@ class TestClusterConductorWithK8s(base.TestCase):
              ],
             env_files)
 
+    @patch('magnum.common.neutron.get_subnet')
     @patch('requests.get')
     @patch('magnum.objects.ClusterTemplate.get_by_uuid')
     @patch('magnum.objects.NodeGroup.list')
@@ -867,7 +936,8 @@ class TestClusterConductorWithK8s(base.TestCase):
             mock_driver,
             mock_objects_nodegroup_list,
             mock_objects_cluster_template_get_by_uuid,
-            mock_get):
+            mock_get,
+            mock_get_subnet):
         mock_driver.return_value = k8s_dr.Driver()
         self._test_extract_template_definition(
             mock_generate_csr_and_key,
@@ -876,8 +946,10 @@ class TestClusterConductorWithK8s(base.TestCase):
             mock_objects_cluster_template_get_by_uuid,
             mock_get,
             mock_objects_nodegroup_list,
+            mock_get_subnet,
             missing_attr='dns_nameserver')
 
+    @patch('magnum.common.neutron.get_subnet')
     @patch('requests.get')
     @patch('magnum.objects.ClusterTemplate.get_by_uuid')
     @patch('magnum.objects.NodeGroup.list')
@@ -892,7 +964,8 @@ class TestClusterConductorWithK8s(base.TestCase):
             mock_driver,
             mock_objects_nodegroup_list,
             mock_objects_cluster_template_get_by_uuid,
-            mock_get):
+            mock_get,
+            mock_get_subnet):
         mock_driver.return_value = k8s_dr.Driver()
         self._test_extract_template_definition(
             mock_generate_csr_and_key,
@@ -901,8 +974,10 @@ class TestClusterConductorWithK8s(base.TestCase):
             mock_objects_cluster_template_get_by_uuid,
             mock_get,
             mock_objects_nodegroup_list,
+            mock_get_subnet,
             missing_attr='image_id')
 
+    @patch('magnum.common.neutron.get_subnet')
     @patch('requests.get')
     @patch('magnum.objects.ClusterTemplate.get_by_uuid')
     @patch('magnum.objects.NodeGroup.list')
@@ -917,7 +992,8 @@ class TestClusterConductorWithK8s(base.TestCase):
             mock_driver,
             mock_objects_nodegroup_list,
             mock_objects_cluster_template_get_by_uuid,
-            mock_get):
+            mock_get,
+            mock_get_subnet):
         mock_driver.return_value = k8s_dr.Driver()
         self._test_extract_template_definition(
             mock_generate_csr_and_key,
@@ -926,8 +1002,10 @@ class TestClusterConductorWithK8s(base.TestCase):
             mock_objects_cluster_template_get_by_uuid,
             mock_get,
             mock_objects_nodegroup_list,
+            mock_get_subnet,
             missing_attr='docker_storage_driver')
 
+    @patch('magnum.common.neutron.get_subnet')
     @patch('requests.get')
     @patch('magnum.objects.ClusterTemplate.get_by_uuid')
     @patch('magnum.objects.NodeGroup.list')
@@ -942,7 +1020,8 @@ class TestClusterConductorWithK8s(base.TestCase):
             mock_driver,
             mock_objects_nodegroup_list,
             mock_objects_cluster_template_get_by_uuid,
-            mock_get):
+            mock_get,
+            mock_get_subnet):
         mock_driver.return_value = k8s_dr.Driver()
         self._test_extract_template_definition(
             mock_generate_csr_and_key,
@@ -951,8 +1030,10 @@ class TestClusterConductorWithK8s(base.TestCase):
             mock_objects_cluster_template_get_by_uuid,
             mock_get,
             mock_objects_nodegroup_list,
+            mock_get_subnet,
             missing_attr='apiserver_port')
 
+    @patch('magnum.common.neutron.get_subnet')
     @patch('requests.get')
     @patch('magnum.objects.ClusterTemplate.get_by_uuid')
     @patch('magnum.objects.NodeGroup.list')
@@ -967,7 +1048,8 @@ class TestClusterConductorWithK8s(base.TestCase):
             mock_driver,
             mock_objects_nodegroup_list,
             mock_objects_cluster_template_get_by_uuid,
-            reqget):
+            reqget,
+            mock_get_subnet):
         cluster_template = objects.ClusterTemplate(
             self.context, **self.cluster_template_dict)
         mock_generate_csr_and_key.return_value = {'csr': 'csr',
@@ -990,6 +1072,7 @@ class TestClusterConductorWithK8s(base.TestCase):
         mock_req = mock.MagicMock(text='https://address/token',
                                   status_code=200)
         reqget.return_value = mock_req
+        mock_get_subnet.return_value = self.fixed_subnet_cidr
 
         (template_path,
          definition,
@@ -1002,9 +1085,10 @@ class TestClusterConductorWithK8s(base.TestCase):
             'external_network': 'e2a6c8b0-a3c2-42a3-b3f4-01400a30896e',
             'fixed_network': 'fixed_network',
             'fixed_network_name': 'fixed_network',
-            'fixed_subnet': 'fixed_subnet',
+            'fixed_subnet': 'c2a6c8b0-a3c2-42a3-b3f4-01400a30896f',
             'dns_nameserver': 'dns_nameserver',
-            'server_image': 'image_id',
+            'master_image': 'image_id',
+            'minion_image': 'image_id',
             'master_flavor': 'master_flavor_id',
             'minion_flavor': 'flavor_id',
             'number_of_minions': 1,
@@ -1016,9 +1100,10 @@ class TestClusterConductorWithK8s(base.TestCase):
             'docker_storage_driver': 'devicemapper',
             'discovery_url': 'https://address/token',
             'etcd_volume_size': None,
+            'etcd_volume_type': '',
             'http_proxy': 'http_proxy',
             'https_proxy': 'https_proxy',
-            'no_proxy': 'no_proxy',
+            'no_proxy': 'no_proxy,20.200.0.0/16',
             'flannel_network_cidr': '10.101.0.0/16',
             'flannel_network_subnetlen': '26',
             'flannel_backend': 'vxlan',
@@ -1045,6 +1130,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'kube_version': 'fake-version',
             'verify_ca': True,
             'openstack_ca': '',
+            'ssh_public_key': 'ssh-rsa AAAAB3Nz',
             "nodes_affinity_policy": "soft-anti-affinity",
             'availability_zone': 'az_1',
             'cert_manager_api': 'False',
@@ -1067,7 +1153,13 @@ class TestClusterConductorWithK8s(base.TestCase):
             'keystone_auth_default_policy': self.keystone_auth_default_policy,
             'boot_volume_size': '60',
             'boot_volume_type': 'lvmdriver-1',
-            'etcd_volume_type': 'lvmdriver-1'
+            'master_role': 'master',
+            'worker_role': 'worker',
+            'master_nodegroup_name': 'master_ng',
+            'worker_nodegroup_name': 'worker_ng',
+            'post_install_manifest_url': '',
+            'master_lb_allowed_cidrs': None,
+            'fixed_subnet_cidr': self.fixed_subnet_cidr,
         }
         self.assertEqual(expected, definition)
         self.assertEqual(
@@ -1113,7 +1205,7 @@ class TestClusterConductorWithK8s(base.TestCase):
 
         expected_args = {
             'stack_name': expected_stack_name,
-            'parameters': {},
+            'parameters': {'is_cluster_stack': True},
             'template': expected_template_contents,
             'files': {},
             'environment_files': [],
@@ -1153,7 +1245,7 @@ class TestClusterConductorWithK8s(base.TestCase):
 
         expected_args = {
             'stack_name': expected_stack_name,
-            'parameters': {},
+            'parameters': {'is_cluster_stack': True},
             'template': expected_template_contents,
             'files': {},
             'environment_files': [],
@@ -1195,7 +1287,7 @@ class TestClusterConductorWithK8s(base.TestCase):
 
         expected_args = {
             'stack_name': expected_stack_name,
-            'parameters': {},
+            'parameters': {'is_cluster_stack': True},
             'template': expected_template_contents,
             'files': {},
             'environment_files': [],
@@ -1229,13 +1321,14 @@ class TestClusterConductorWithK8s(base.TestCase):
         mock_cluster.cluster_template = mock_template
         self.worker_ng_dict['node_count'] = 2
         worker_ng = objects.NodeGroup(self.context, **self.worker_ng_dict)
+        worker_ng.stack_id = mock_stack_id
         master_ng = objects.NodeGroup(self.context, **self.master_ng_dict)
         mock_objects_nodegroup_list.return_value = [master_ng, worker_ng]
 
         k8s_dr.Driver().update_cluster({}, mock_cluster)
 
         expected_args = {
-            'parameters': {'number_of_minions': '2'},
+            'parameters': {'number_of_minions': 2},
             'existing': True,
             'disable_rollback': True
         }
