@@ -75,6 +75,7 @@ class TestClusterConductorWithMesos(base.TestCase):
             'fixed_network': '',
             'fixed_subnet': '',
             'floating_ip_enabled': False,
+            'master_lb_enabled': False,
         }
         self.worker_ng_dict = {
             'uuid': '5d12f6fd-a196-4bf0-ae4c-1f639a523a53',
@@ -116,6 +117,13 @@ class TestClusterConductorWithMesos(base.TestCase):
         self.addCleanup(osc_patcher.stop)
         self.mock_osc = mock.MagicMock()
         self.mock_osc.cinder_region_name.return_value = 'RegionOne'
+
+        mock_keypair = mock.MagicMock()
+        mock_keypair.public_key = 'ssh-rsa AAAAB3Nz'
+        self.mock_nova = mock.MagicMock()
+        self.mock_nova.keypairs.get.return_value = mock_keypair
+        self.mock_osc.nova.return_value = self.mock_nova
+
         self.mock_keystone = mock.MagicMock()
         self.mock_keystone.trustee_domain_id = 'trustee_domain_id'
         self.mock_osc.keystone.return_value = self.mock_keystone
@@ -147,11 +155,13 @@ class TestClusterConductorWithMesos(base.TestCase):
 
         expected = {
             'ssh_key_name': 'keypair_id',
+            'ssh_public_key': 'ssh-rsa AAAAB3Nz',
             'external_network': 'external_network_id',
             'fixed_network': 'fixed_network',
             'fixed_subnet': 'fixed_subnet',
             'dns_nameserver': 'dns_nameserver',
-            'server_image': 'image_id',
+            'master_image': 'image_id',
+            'slave_image': 'image_id',
             'master_flavor': 'master_flavor_id',
             'slave_flavor': 'flavor_id',
             'number_of_slaves': 1,
@@ -178,7 +188,7 @@ class TestClusterConductorWithMesos(base.TestCase):
             'mesos_slave_image_providers': 'docker',
             'verify_ca': True,
             'openstack_ca': '',
-            'nodes_affinity_policy': 'soft-anti-affinity'
+            'nodes_affinity_policy': 'soft-anti-affinity',
         }
         self.assertEqual(expected, definition)
         self.assertEqual(
@@ -206,6 +216,8 @@ class TestClusterConductorWithMesos(base.TestCase):
         mock_objects_cluster_template_get_by_uuid.return_value = \
             cluster_template
         cluster = objects.Cluster(self.context, **self.cluster_dict)
+        del self.worker_ng_dict['image_id']
+        del self.master_ng_dict['image_id']
         worker_ng = objects.NodeGroup(self.context, **self.worker_ng_dict)
         master_ng = objects.NodeGroup(self.context, **self.master_ng_dict)
         mock_objects_nodegroup_list.return_value = [master_ng, worker_ng]
@@ -218,6 +230,7 @@ class TestClusterConductorWithMesos(base.TestCase):
 
         expected = {
             'ssh_key_name': 'keypair_id',
+            'ssh_public_key': 'ssh-rsa AAAAB3Nz',
             'external_network': 'external_network_id',
             'number_of_slaves': 1,
             'number_of_masters': 1,
@@ -241,7 +254,7 @@ class TestClusterConductorWithMesos(base.TestCase):
             'verify_ca': True,
             'slave_flavor': 'flavor_id',
             'openstack_ca': '',
-            'nodes_affinity_policy': 'soft-anti-affinity'
+            'nodes_affinity_policy': 'soft-anti-affinity',
         }
         self.assertEqual(expected, definition)
         self.assertEqual(
@@ -264,6 +277,7 @@ class TestClusterConductorWithMesos(base.TestCase):
             self.context, **self.cluster_template_dict)
         mock_objects_cluster_template_get_by_uuid.return_value = \
             cluster_template
+        self.cluster_dict["master_lb_enabled"] = True
         cluster = objects.Cluster(self.context, **self.cluster_dict)
         worker_ng = objects.NodeGroup(self.context, **self.worker_ng_dict)
         master_ng = objects.NodeGroup(self.context, **self.master_ng_dict)
@@ -279,11 +293,13 @@ class TestClusterConductorWithMesos(base.TestCase):
 
         expected = {
             'ssh_key_name': 'keypair_id',
+            'ssh_public_key': 'ssh-rsa AAAAB3Nz',
             'external_network': 'external_network_id',
             'fixed_network': 'fixed_network',
             'fixed_subnet': 'fixed_subnet',
             'dns_nameserver': 'dns_nameserver',
-            'server_image': 'image_id',
+            'master_image': 'image_id',
+            'slave_image': 'image_id',
             'master_flavor': 'master_flavor_id',
             'slave_flavor': 'flavor_id',
             'number_of_slaves': 1,
@@ -310,7 +326,7 @@ class TestClusterConductorWithMesos(base.TestCase):
             'mesos_slave_image_providers': 'docker',
             'verify_ca': True,
             'openstack_ca': '',
-            'nodes_affinity_policy': 'soft-anti-affinity'
+            'nodes_affinity_policy': 'soft-anti-affinity',
         }
         self.assertEqual(expected, definition)
         self.assertEqual(
@@ -333,6 +349,7 @@ class TestClusterConductorWithMesos(base.TestCase):
             self.context, **self.cluster_template_dict)
         mock_objects_cluster_template_get_by_uuid.return_value = \
             cluster_template
+        self.cluster_dict["master_lb_enabled"] = True
         cluster = objects.Cluster(self.context, **self.cluster_dict)
         worker_ng = objects.NodeGroup(self.context, **self.worker_ng_dict)
         master_ng = objects.NodeGroup(self.context, **self.master_ng_dict)
@@ -352,11 +369,13 @@ class TestClusterConductorWithMesos(base.TestCase):
 
         expected = {
             'ssh_key_name': 'keypair_id',
+            'ssh_public_key': 'ssh-rsa AAAAB3Nz',
             'external_network': 'external_network_id',
             'fixed_network': 'fixed_network',
             'fixed_subnet': 'fixed_subnet',
             'dns_nameserver': 'dns_nameserver',
-            'server_image': 'image_id',
+            'master_image': 'image_id',
+            'slave_image': 'image_id',
             'master_flavor': 'master_flavor_id',
             'slave_flavor': 'flavor_id',
             'number_of_slaves': 1,
@@ -383,7 +402,7 @@ class TestClusterConductorWithMesos(base.TestCase):
             'mesos_slave_image_providers': 'docker',
             'verify_ca': True,
             'openstack_ca': '',
-            'nodes_affinity_policy': 'soft-anti-affinity'
+            'nodes_affinity_policy': 'soft-anti-affinity',
         }
         self.assertEqual(expected, definition)
         self.assertEqual(
@@ -408,6 +427,7 @@ class TestClusterConductorWithMesos(base.TestCase):
             self.context, **self.cluster_template_dict)
         mock_objects_cluster_template_get_by_uuid.return_value = \
             cluster_template
+        self.cluster_dict["master_lb_enabled"] = True
         cluster = objects.Cluster(self.context, **self.cluster_dict)
         worker_ng = objects.NodeGroup(self.context, **self.worker_ng_dict)
         master_ng = objects.NodeGroup(self.context, **self.master_ng_dict)
@@ -423,11 +443,13 @@ class TestClusterConductorWithMesos(base.TestCase):
 
         expected = {
             'ssh_key_name': 'keypair_id',
+            'ssh_public_key': 'ssh-rsa AAAAB3Nz',
             'external_network': 'external_network_id',
             'fixed_network': 'fixed_network',
             'fixed_subnet': 'fixed_subnet',
             'dns_nameserver': 'dns_nameserver',
-            'server_image': 'image_id',
+            'master_image': 'image_id',
+            'slave_image': 'image_id',
             'master_flavor': 'master_flavor_id',
             'slave_flavor': 'flavor_id',
             'number_of_slaves': 1,
@@ -454,7 +476,7 @@ class TestClusterConductorWithMesos(base.TestCase):
             'mesos_slave_image_providers': 'docker',
             'verify_ca': True,
             'openstack_ca': '',
-            'nodes_affinity_policy': 'soft-anti-affinity'
+            'nodes_affinity_policy': 'soft-anti-affinity',
         }
         self.assertEqual(expected, definition)
         self.assertEqual(
