@@ -85,6 +85,7 @@ class TestClusterConductorWithSwarm(base.TestCase):
             'fixed_network': '',
             'fixed_subnet': '',
             'floating_ip_enabled': False,
+            'master_lb_enabled': False,
         }
         self.worker_ng_dict = {
             'uuid': '5d12f6fd-a196-4bf0-ae4c-1f639a523a53',
@@ -130,6 +131,13 @@ class TestClusterConductorWithSwarm(base.TestCase):
         self.mock_osc = mock.MagicMock()
         self.mock_osc.magnum_url.return_value = 'http://127.0.0.1:9511/v1'
         self.mock_osc.url_for.return_value = 'http://192.168.10.10:5000/v3'
+
+        mock_keypair = mock.MagicMock()
+        mock_keypair.public_key = 'ssh-rsa AAAAB3Nz'
+        self.mock_nova = mock.MagicMock()
+        self.mock_nova.keypairs.get.return_value = mock_keypair
+        self.mock_osc.nova.return_value = self.mock_nova
+
         self.mock_keystone = mock.MagicMock()
         self.mock_keystone.trustee_domain_id = 'trustee_domain_id'
         self.mock_osc.keystone.return_value = self.mock_keystone
@@ -167,11 +175,13 @@ class TestClusterConductorWithSwarm(base.TestCase):
 
         expected = {
             'ssh_key_name': 'keypair_id',
+            'ssh_public_key': 'ssh-rsa AAAAB3Nz',
             'external_network': 'external_network_id',
             'fixed_network': 'fixed_network',
             'fixed_subnet': 'fixed_subnet',
             'dns_nameserver': 'dns_nameserver',
-            'server_image': 'image_id',
+            'master_image': 'image_id',
+            'node_image': 'image_id',
             'master_flavor': 'master_flavor_id',
             'node_flavor': 'flavor_id',
             'number_of_masters': 1,
@@ -203,7 +213,7 @@ class TestClusterConductorWithSwarm(base.TestCase):
             'docker_volume_type': 'lvmdriver-1',
             'verify_ca': True,
             'openstack_ca': '',
-            'nodes_affinity_policy': 'soft-anti-affinity'
+            'nodes_affinity_policy': 'soft-anti-affinity',
         }
         self.assertEqual(expected, definition)
         self.assertEqual(
@@ -249,11 +259,13 @@ class TestClusterConductorWithSwarm(base.TestCase):
 
         expected = {
             'ssh_key_name': 'keypair_id',
+            'ssh_public_key': 'ssh-rsa AAAAB3Nz',
             'external_network': 'external_network_id',
             'fixed_network': 'fixed_network',
             'fixed_subnet': 'fixed_subnet',
             'dns_nameserver': 'dns_nameserver',
-            'server_image': 'image_id',
+            'master_image': 'image_id',
+            'node_image': 'image_id',
             'master_flavor': 'master_flavor_id',
             'node_flavor': 'flavor_id',
             'number_of_masters': 1,
@@ -287,7 +299,7 @@ class TestClusterConductorWithSwarm(base.TestCase):
             'docker_volume_type': 'lvmdriver-1',
             'verify_ca': True,
             'openstack_ca': '',
-            'nodes_affinity_policy': 'soft-anti-affinity'
+            'nodes_affinity_policy': 'soft-anti-affinity',
         }
         self.assertEqual(expected, definition)
         self.assertEqual(
@@ -328,6 +340,8 @@ class TestClusterConductorWithSwarm(base.TestCase):
         mock_get.return_value = mock_resp
         mock_driver.return_value = swarm_dr.Driver()
         cluster = objects.Cluster(self.context, **self.cluster_dict)
+        del self.worker_ng_dict['image_id']
+        del self.master_ng_dict['image_id']
         worker_ng = objects.NodeGroup(self.context, **self.worker_ng_dict)
         master_ng = objects.NodeGroup(self.context, **self.master_ng_dict)
         mock_objects_nodegroup_list.return_value = [master_ng, worker_ng]
@@ -339,6 +353,7 @@ class TestClusterConductorWithSwarm(base.TestCase):
 
         expected = {
             'ssh_key_name': 'keypair_id',
+            'ssh_public_key': 'ssh-rsa AAAAB3Nz',
             'external_network': 'external_network_id',
             'number_of_masters': 1,
             'number_of_nodes': 1,
@@ -365,7 +380,7 @@ class TestClusterConductorWithSwarm(base.TestCase):
             'verify_ca': True,
             'node_flavor': 'flavor_id',
             'openstack_ca': '',
-            'nodes_affinity_policy': 'soft-anti-affinity'
+            'nodes_affinity_policy': 'soft-anti-affinity',
         }
         self.assertEqual(expected, definition)
         self.assertEqual(
@@ -397,6 +412,7 @@ class TestClusterConductorWithSwarm(base.TestCase):
         mock_resp.text = expected_result
         mock_get.return_value = mock_resp
         mock_driver.return_value = swarm_dr.Driver()
+        self.cluster_dict["master_lb_enabled"] = True
         cluster = objects.Cluster(self.context, **self.cluster_dict)
         worker_ng = objects.NodeGroup(self.context, **self.worker_ng_dict)
         master_ng = objects.NodeGroup(self.context, **self.master_ng_dict)
@@ -411,11 +427,13 @@ class TestClusterConductorWithSwarm(base.TestCase):
 
         expected = {
             'ssh_key_name': 'keypair_id',
+            'ssh_public_key': 'ssh-rsa AAAAB3Nz',
             'external_network': 'external_network_id',
             'fixed_network': 'fixed_network',
             'fixed_subnet': 'fixed_subnet',
             'dns_nameserver': 'dns_nameserver',
-            'server_image': 'image_id',
+            'master_image': 'image_id',
+            'node_image': 'image_id',
             'master_flavor': 'master_flavor_id',
             'node_flavor': 'flavor_id',
             'number_of_masters': 1,
@@ -447,7 +465,7 @@ class TestClusterConductorWithSwarm(base.TestCase):
             'docker_volume_type': 'lvmdriver-1',
             'verify_ca': True,
             'openstack_ca': '',
-            'nodes_affinity_policy': 'soft-anti-affinity'
+            'nodes_affinity_policy': 'soft-anti-affinity',
         }
         self.assertEqual(expected, definition)
         self.assertEqual(
@@ -479,6 +497,7 @@ class TestClusterConductorWithSwarm(base.TestCase):
         mock_resp.text = expected_result
         mock_get.return_value = mock_resp
         mock_driver.return_value = swarm_dr.Driver()
+        self.cluster_dict["master_lb_enabled"] = True
         cluster = objects.Cluster(self.context, **self.cluster_dict)
         worker_ng = objects.NodeGroup(self.context, **self.worker_ng_dict)
         master_ng = objects.NodeGroup(self.context, **self.master_ng_dict)
@@ -497,11 +516,13 @@ class TestClusterConductorWithSwarm(base.TestCase):
 
         expected = {
             'ssh_key_name': 'keypair_id',
+            'ssh_public_key': 'ssh-rsa AAAAB3Nz',
             'external_network': 'external_network_id',
             'fixed_network': 'fixed_network',
             'fixed_subnet': 'fixed_subnet',
             'dns_nameserver': 'dns_nameserver',
-            'server_image': 'image_id',
+            'master_image': 'image_id',
+            'node_image': 'image_id',
             'master_flavor': 'master_flavor_id',
             'node_flavor': 'flavor_id',
             'number_of_masters': 1,
@@ -533,7 +554,7 @@ class TestClusterConductorWithSwarm(base.TestCase):
             'docker_volume_type': 'lvmdriver-1',
             'verify_ca': True,
             'openstack_ca': '',
-            'nodes_affinity_policy': 'soft-anti-affinity'
+            'nodes_affinity_policy': 'soft-anti-affinity',
         }
         self.assertEqual(expected, definition)
         self.assertEqual(
@@ -567,6 +588,7 @@ class TestClusterConductorWithSwarm(base.TestCase):
         mock_resp.text = expected_result
         mock_get.return_value = mock_resp
         mock_driver.return_value = swarm_dr.Driver()
+        self.cluster_dict["master_lb_enabled"] = True
         cluster = objects.Cluster(self.context, **self.cluster_dict)
         worker_ng = objects.NodeGroup(self.context, **self.worker_ng_dict)
         master_ng = objects.NodeGroup(self.context, **self.master_ng_dict)
@@ -581,11 +603,13 @@ class TestClusterConductorWithSwarm(base.TestCase):
 
         expected = {
             'ssh_key_name': 'keypair_id',
+            'ssh_public_key': 'ssh-rsa AAAAB3Nz',
             'external_network': 'external_network_id',
             'fixed_network': 'fixed_network',
             'fixed_subnet': 'fixed_subnet',
             'dns_nameserver': 'dns_nameserver',
-            'server_image': 'image_id',
+            'master_image': 'image_id',
+            'node_image': 'image_id',
             'master_flavor': 'master_flavor_id',
             'node_flavor': 'flavor_id',
             'number_of_masters': 2,
@@ -617,7 +641,7 @@ class TestClusterConductorWithSwarm(base.TestCase):
             'docker_volume_type': 'lvmdriver-1',
             'verify_ca': True,
             'openstack_ca': '',
-            'nodes_affinity_policy': 'soft-anti-affinity'
+            'nodes_affinity_policy': 'soft-anti-affinity',
         }
         self.assertEqual(expected, definition)
         self.assertEqual(
