@@ -149,24 +149,25 @@ class TemplateDefinitionTestCase(base.TestCase):
         ]
 
         mock_stack = mock.MagicMock()
+        mock_cluster = mock.MagicMock()
         mock_stack.to_dict.return_value = {'outputs': heat_outputs}
 
         output = cmn_tdef.OutputMapping('key1')
-        value = output.get_output_value(mock_stack)
+        value = output.get_output_value(mock_stack, mock_cluster)
         self.assertEqual('value1', value)
 
         output = cmn_tdef.OutputMapping('key2')
-        value = output.get_output_value(mock_stack)
+        value = output.get_output_value(mock_stack, mock_cluster)
         self.assertEqual(["value2", "value3"], value)
 
         output = cmn_tdef.OutputMapping('key3')
-        value = output.get_output_value(mock_stack)
+        value = output.get_output_value(mock_stack, mock_cluster)
         self.assertIsNone(value)
 
         # verify stack with no 'outputs' attribute
         mock_stack.to_dict.return_value = {}
         output = cmn_tdef.OutputMapping('key1')
-        value = output.get_output_value(mock_stack)
+        value = output.get_output_value(mock_stack, mock_cluster)
         self.assertIsNone(value)
 
     def test_add_output_with_mapping_type(self):
@@ -184,13 +185,9 @@ class TemplateDefinitionTestCase(base.TestCase):
                       definition.output_mappings)
 
     def test_add_fip_env_lb_disabled_with_fp(self):
-        mock_cluster_template = mock.MagicMock(floating_ip_enabled=True,
-                                               master_lb_enabled=False,
-                                               labels={})
-        mock_cluster = mock.MagicMock(labels={})
+        mock_cluster = mock.MagicMock(master_lb_enabled=False, labels={})
         env_files = []
-        cmn_tdef.add_fip_env_file(env_files, mock_cluster_template,
-                                  mock_cluster)
+        cmn_tdef.add_fip_env_file(env_files, mock_cluster)
         self.assertEqual(
             [
                 cmn_tdef.COMMON_ENV_PATH + 'enable_floating_ip.yaml',
@@ -200,13 +197,11 @@ class TemplateDefinitionTestCase(base.TestCase):
         )
 
     def test_add_fip_env_lb_enabled_with_fp(self):
-        mock_cluster_template = mock.MagicMock(floating_ip_enabled=True,
-                                               master_lb_enabled=True,
-                                               labels={})
-        mock_cluster = mock.MagicMock(floating_ip_enabled=True, labels={})
+        mock_cluster = mock.MagicMock(floating_ip_enabled=True,
+                                      master_lb_enabled=True,
+                                      labels={})
         env_files = []
-        cmn_tdef.add_fip_env_file(env_files, mock_cluster_template,
-                                  mock_cluster)
+        cmn_tdef.add_fip_env_file(env_files, mock_cluster)
         self.assertEqual(
             [
                 cmn_tdef.COMMON_ENV_PATH + 'enable_floating_ip.yaml',
@@ -216,13 +211,9 @@ class TemplateDefinitionTestCase(base.TestCase):
         )
 
     def test_add_fip_env_lb_disabled_without_fp(self):
-        mock_cluster_template = mock.MagicMock(floating_ip_enabled=False,
-                                               master_lb_enabled=False,
-                                               labels={})
         mock_cluster = mock.MagicMock(labels={}, floating_ip_enabled=False)
         env_files = []
-        cmn_tdef.add_fip_env_file(env_files, mock_cluster_template,
-                                  mock_cluster)
+        cmn_tdef.add_fip_env_file(env_files, mock_cluster)
         self.assertEqual(
             [
                 cmn_tdef.COMMON_ENV_PATH + 'disable_floating_ip.yaml',
@@ -232,13 +223,9 @@ class TemplateDefinitionTestCase(base.TestCase):
         )
 
     def test_add_fip_env_lb_enabled_without_fp(self):
-        mock_cluster_template = mock.MagicMock(floating_ip_enabled=False,
-                                               master_lb_enabled=True,
-                                               labels={})
         mock_cluster = mock.MagicMock(labels={}, floating_ip_enabled=False,)
         env_files = []
-        cmn_tdef.add_fip_env_file(env_files, mock_cluster_template,
-                                  mock_cluster)
+        cmn_tdef.add_fip_env_file(env_files, mock_cluster)
         self.assertEqual(
             [
                 cmn_tdef.COMMON_ENV_PATH + 'disable_floating_ip.yaml',
@@ -248,17 +235,11 @@ class TemplateDefinitionTestCase(base.TestCase):
         )
 
     def test_add_fip_env_lb_fip_enabled_without_fp(self):
-        mock_cluster_template = mock.MagicMock(
-            floating_ip_enabled=False,
-            master_lb_enabled=True,
-            labels={"master_lb_floating_ip_enabled": "true"}
-        )
         mock_cluster = mock.MagicMock(
             labels={"master_lb_floating_ip_enabled": "true"},
             floating_ip_enabled=False,)
         env_files = []
-        cmn_tdef.add_fip_env_file(env_files, mock_cluster_template,
-                                  mock_cluster)
+        cmn_tdef.add_fip_env_file(env_files, mock_cluster)
         self.assertEqual(
             [
                 cmn_tdef.COMMON_ENV_PATH + 'disable_floating_ip.yaml',
@@ -268,18 +249,12 @@ class TemplateDefinitionTestCase(base.TestCase):
         )
 
     def test_add_fip_env_lb_enable_lbfip_disable(self):
-        mock_cluster_template = mock.MagicMock(
-            floating_ip_enabled=False,
-            master_lb_enabled=True,
-            labels={"master_lb_floating_ip_enabled": "false"}
-        )
         mock_cluster = mock.MagicMock(
             labels={"master_lb_floating_ip_enabled": "false"},
             floating_ip_enabled=False,)
         env_files = []
 
-        cmn_tdef.add_fip_env_file(env_files, mock_cluster_template,
-                                  mock_cluster)
+        cmn_tdef.add_fip_env_file(env_files, mock_cluster)
 
         self.assertEqual(
             [
@@ -290,18 +265,12 @@ class TemplateDefinitionTestCase(base.TestCase):
         )
 
     def test_add_fip_env_lb_enable_lbfip_template_disable_cluster_enable(self):
-        mock_cluster_template = mock.MagicMock(
-            floating_ip_enabled=False,
-            master_lb_enabled=True,
-            labels={}
-        )
         mock_cluster = mock.MagicMock(
             floating_ip_enabled=True,
             labels={})
         env_files = []
 
-        cmn_tdef.add_fip_env_file(env_files, mock_cluster_template,
-                                  mock_cluster)
+        cmn_tdef.add_fip_env_file(env_files, mock_cluster)
 
         self.assertEqual(
             [
@@ -312,18 +281,12 @@ class TemplateDefinitionTestCase(base.TestCase):
         )
 
     def test_add_fip_master_lb_fip_disabled_cluster_fip_enabled(self):
-        mock_cluster_template = mock.MagicMock(
-            floating_ip_enabled=False,
-            master_lb_enabled=True,
-            labels={"master_lb_floating_ip_enabled": "false"}
-        )
         mock_cluster = mock.MagicMock(
             labels={"master_lb_floating_ip_enabled": "false"},
             floating_ip_enabled=True,)
         env_files = []
 
-        cmn_tdef.add_fip_env_file(env_files, mock_cluster_template,
-                                  mock_cluster)
+        cmn_tdef.add_fip_env_file(env_files, mock_cluster)
 
         self.assertEqual(
             [
@@ -333,18 +296,6 @@ class TemplateDefinitionTestCase(base.TestCase):
             env_files
         )
 
-    @mock.patch('magnum.drivers.common.driver.Driver.get_driver')
-    def test_base_get_scale_params(self, mock_driver):
-        mock_context = mock.MagicMock()
-        mock_cluster = mock.MagicMock()
-        mock_driver.return_value = swarm_v2_dr.Driver()
-        cluster_driver = driver.Driver.get_driver('vm',
-                                                  'fedora-atomic',
-                                                  'swarm-mode')
-        definition = cluster_driver.get_template_definition()
-        self.assertEqual(definition.get_scale_params(mock_context,
-                                                     mock_cluster), {})
-
 
 @six.add_metaclass(abc.ABCMeta)
 class BaseK8sTemplateDefinitionTestCase(base.TestCase):
@@ -391,6 +342,7 @@ class BaseK8sTemplateDefinitionTestCase(base.TestCase):
         mock_stack.to_dict.return_value = {'outputs': outputs}
         mock_cluster_template = mock.MagicMock()
         mock_cluster_template.floating_ip_enabled = floating_ip_enabled
+        self.mock_cluster.floating_ip_enabled = floating_ip_enabled
 
         definition.update_outputs(mock_stack, mock_cluster_template,
                                   self.mock_cluster)
@@ -422,16 +374,24 @@ class AtomicK8sTemplateDefinitionTestCase(BaseK8sTemplateDefinitionTestCase):
         mock_cluster = mock.MagicMock()
 
         removal_nodes = ['node1', 'node2']
+        node_count = 5
         mock_scale_manager = mock.MagicMock()
         mock_scale_manager.get_removal_nodes.return_value = removal_nodes
 
         definition = k8sa_tdef.AtomicK8sTemplateDefinition()
 
         scale_params = definition.get_scale_params(mock_context, mock_cluster,
+                                                   node_count,
                                                    mock_scale_manager)
-        expected_scale_params = {'minions_to_remove': ['node1', 'node2']}
+        expected_scale_params = {
+            'minions_to_remove': ['node1', 'node2'],
+            'number_of_minions': 5
+        }
         self.assertEqual(scale_params, expected_scale_params)
 
+    @mock.patch('magnum.common.neutron.get_subnet')
+    @mock.patch('magnum.drivers.heat.k8s_template_def.K8sTemplateDefinition'
+                '._set_master_lb_allowed_cidrs')
     @mock.patch('magnum.common.neutron.get_fixed_network_name')
     @mock.patch('magnum.common.keystone.is_octavia_enabled')
     @mock.patch('magnum.common.clients.OpenStackClients')
@@ -449,7 +409,9 @@ class AtomicK8sTemplateDefinitionTestCase(BaseK8sTemplateDefinitionTestCase):
                             mock_get_output, mock_get_params,
                             mock_get_discovery_url, mock_osc_class,
                             mock_enable_octavia,
-                            mock_get_fixed_network_name):
+                            mock_get_fixed_network_name,
+                            mock_set_master_lb_allowed_cidrs,
+                            mock_get_subnet):
         mock_generate_csr_and_key.return_value = {'csr': 'csr',
                                                   'private_key': 'private_key',
                                                   'public_key': 'public_key'}
@@ -463,6 +425,7 @@ class AtomicK8sTemplateDefinitionTestCase(BaseK8sTemplateDefinitionTestCase):
         mock_cluster_template.network_driver = 'flannel'
         external_network_id = '17e4e301-b7f3-4996-b3dd-97b3a700174b'
         mock_cluster_template.external_network_id = external_network_id
+        mock_cluster_template.no_proxy = ""
         mock_cluster = mock.MagicMock()
         fixed_network_name = 'fixed_network'
         mock_get_fixed_network_name.return_value = fixed_network_name
@@ -481,6 +444,7 @@ class AtomicK8sTemplateDefinitionTestCase(BaseK8sTemplateDefinitionTestCase):
 
         mock_context.auth_url = 'http://192.168.10.10:5000/v3'
         mock_context.user_name = 'fake_user'
+        mock_get_subnet.return_value = '20.200.0.0/16'
 
         flannel_cidr = mock_cluster.labels.get('flannel_network_cidr')
         flannel_subnet = mock_cluster.labels.get(
@@ -589,6 +553,10 @@ class AtomicK8sTemplateDefinitionTestCase(BaseK8sTemplateDefinitionTestCase):
             'tiller_tag')
         tiller_namespace = mock_cluster.labels.get(
             'tiller_namespace')
+        helm_client_url = mock_cluster.labels.get(
+            'helm_client_url')
+        helm_client_sha256 = mock_cluster.labels.get(
+            'helm_client_sha256')
         helm_client_tag = mock_cluster.labels.get(
             'helm_client_tag')
         npd_tag = mock_cluster.labels.get('node_problem_detector_tag')
@@ -636,6 +604,8 @@ class AtomicK8sTemplateDefinitionTestCase(BaseK8sTemplateDefinitionTestCase):
             'containerd_tarball_sha256')
         kube_image_digest = mock_cluster.labels.get('kube_image_digest')
         metrics_scraper_tag = mock_cluster.labels.get('metrics_scraper_tag')
+        master_lb_allowed_cidrs = mock_cluster.labels.get(
+            'master_lb_allowed_cidrs')
 
         k8s_def = k8sa_tdef.AtomicK8sTemplateDefinition()
 
@@ -712,6 +682,8 @@ class AtomicK8sTemplateDefinitionTestCase(BaseK8sTemplateDefinitionTestCase):
             'tiller_enabled': tiller_enabled,
             'tiller_tag': tiller_tag,
             'tiller_namespace': tiller_namespace,
+            'helm_client_url': helm_client_url,
+            'helm_client_sha256': helm_client_sha256,
             'helm_client_tag': helm_client_tag,
             'node_problem_detector_tag': npd_tag,
             'auto_healing_enabled': auto_healing_enabled,
@@ -748,6 +720,8 @@ class AtomicK8sTemplateDefinitionTestCase(BaseK8sTemplateDefinitionTestCase):
             'containerd_tarball_sha256': containerd_tarball_sha256,
             'post_install_manifest_url': '',
             'metrics_scraper_tag': metrics_scraper_tag,
+            'master_lb_allowed_cidrs': master_lb_allowed_cidrs,
+            'fixed_subnet_cidr': '20.200.0.0/16',
         }}
         mock_get_params.assert_called_once_with(mock_context,
                                                 mock_cluster_template,
@@ -774,6 +748,7 @@ class AtomicK8sTemplateDefinitionTestCase(BaseK8sTemplateDefinitionTestCase):
             mock_cluster.fixed_network
         )
 
+    @mock.patch('magnum.common.neutron.get_subnet')
     @mock.patch('magnum.common.neutron.get_external_network_id')
     @mock.patch('magnum.common.keystone.is_octavia_enabled')
     @mock.patch('magnum.common.clients.OpenStackClients')
@@ -791,7 +766,8 @@ class AtomicK8sTemplateDefinitionTestCase(BaseK8sTemplateDefinitionTestCase):
                                                 mock_get_discovery_url,
                                                 mock_osc_class,
                                                 mock_enable_octavia,
-                                                mock_get_external_network_id):
+                                                mock_get_external_network_id,
+                                                mock_get_subnet):
         mock_generate_csr_and_key.return_value = {'csr': 'csr',
                                                   'private_key': 'private_key',
                                                   'public_key': 'public_key'}
@@ -835,6 +811,7 @@ class AtomicK8sTemplateDefinitionTestCase(BaseK8sTemplateDefinitionTestCase):
             mock_cluster_template.external_network_id
         )
 
+    @mock.patch('magnum.common.neutron.get_subnet')
     @mock.patch('magnum.common.keystone.is_octavia_enabled')
     @mock.patch('magnum.common.clients.OpenStackClients')
     @mock.patch('magnum.drivers.k8s_fedora_atomic_v1.template_def'
@@ -850,7 +827,8 @@ class AtomicK8sTemplateDefinitionTestCase(BaseK8sTemplateDefinitionTestCase):
                                              mock_get_params,
                                              mock_get_discovery_url,
                                              mock_osc_class,
-                                             mock_enable_octavia):
+                                             mock_enable_octavia,
+                                             mock_get_subnet):
         mock_generate_csr_and_key.return_value = {'csr': 'csr',
                                                   'private_key': 'private_key',
                                                   'public_key': 'public_key'}
@@ -890,6 +868,7 @@ class AtomicK8sTemplateDefinitionTestCase(BaseK8sTemplateDefinitionTestCase):
             mock_cluster,
         )
 
+    @mock.patch('magnum.common.neutron.get_subnet')
     @mock.patch('magnum.common.keystone.is_octavia_enabled')
     @mock.patch('magnum.common.clients.OpenStackClients')
     @mock.patch('magnum.drivers.k8s_fedora_atomic_v1.template_def'
@@ -905,7 +884,8 @@ class AtomicK8sTemplateDefinitionTestCase(BaseK8sTemplateDefinitionTestCase):
                                             mock_get_params,
                                             mock_get_discovery_url,
                                             mock_osc_class,
-                                            mock_enable_octavia):
+                                            mock_enable_octavia,
+                                            mock_get_subnet):
         mock_generate_csr_and_key.return_value = {'csr': 'csr',
                                                   'private_key': 'private_key',
                                                   'public_key': 'public_key'}
@@ -944,6 +924,9 @@ class AtomicK8sTemplateDefinitionTestCase(BaseK8sTemplateDefinitionTestCase):
             actual_params.get("ingress_controller")
         )
 
+    @mock.patch('magnum.common.neutron.get_subnet')
+    @mock.patch('magnum.drivers.heat.k8s_template_def.K8sTemplateDefinition'
+                '._set_master_lb_allowed_cidrs')
     @mock.patch('magnum.common.keystone.is_octavia_enabled')
     @mock.patch('magnum.common.clients.OpenStackClients')
     @mock.patch('magnum.drivers.heat.template_def'
@@ -959,7 +942,9 @@ class AtomicK8sTemplateDefinitionTestCase(BaseK8sTemplateDefinitionTestCase):
                                      mock_sign_node_certificate,
                                      mock_get_output, mock_get_params,
                                      mock_get_discovery_url, mock_osc_class,
-                                     mock_enable_octavia):
+                                     mock_enable_octavia,
+                                     mock_set_master_lb_allowed_cidrs,
+                                     mock_get_subnet):
         mock_generate_csr_and_key.return_value = {'csr': 'csr',
                                                   'private_key': 'private_key',
                                                   'public_key': 'public_key'}
@@ -973,6 +958,7 @@ class AtomicK8sTemplateDefinitionTestCase(BaseK8sTemplateDefinitionTestCase):
         mock_cluster_template.network_driver = 'calico'
         external_network_id = '17e4e301-b7f3-4996-b3dd-97b3a700174b'
         mock_cluster_template.external_network_id = external_network_id
+        mock_cluster_template.no_proxy = ""
         mock_cluster = mock.MagicMock()
         fixed_network_name = 'fixed_network'
         mock_cluster.fixed_network = fixed_network_name
@@ -989,6 +975,7 @@ class AtomicK8sTemplateDefinitionTestCase(BaseK8sTemplateDefinitionTestCase):
 
         mock_context.auth_url = 'http://192.168.10.10:5000/v3'
         mock_context.user_name = 'fake_user'
+        mock_get_subnet.return_value = "20.200.0.0/16"
 
         flannel_cidr = mock_cluster.labels.get('flannel_network_cidr')
         flannel_subnet = mock_cluster.labels.get(
@@ -1097,6 +1084,10 @@ class AtomicK8sTemplateDefinitionTestCase(BaseK8sTemplateDefinitionTestCase):
             'tiller_tag')
         tiller_namespace = mock_cluster.labels.get(
             'tiller_namespace')
+        helm_client_url = mock_cluster.labels.get(
+            'helm_client_url')
+        helm_client_sha256 = mock_cluster.labels.get(
+            'helm_client_sha256')
         helm_client_tag = mock_cluster.labels.get(
             'helm_client_tag')
         npd_tag = mock_cluster.labels.get('node_problem_detector_tag')
@@ -1145,6 +1136,9 @@ class AtomicK8sTemplateDefinitionTestCase(BaseK8sTemplateDefinitionTestCase):
         kube_image_digest = mock_cluster.labels.get('kube_image_digest')
         metrics_scraper_tag = mock_cluster.labels.get('metrics_scraper_tag')
 
+        master_lb_allowed_cidrs = mock_cluster.labels.get(
+            'master_lb_allowed_cidrs')
+
         k8s_def = k8sa_tdef.AtomicK8sTemplateDefinition()
 
         k8s_def.get_params(mock_context, mock_cluster_template, mock_cluster)
@@ -1222,6 +1216,8 @@ class AtomicK8sTemplateDefinitionTestCase(BaseK8sTemplateDefinitionTestCase):
             'tiller_enabled': tiller_enabled,
             'tiller_tag': tiller_tag,
             'tiller_namespace': tiller_namespace,
+            'helm_client_url': helm_client_url,
+            'helm_client_sha256': helm_client_sha256,
             'helm_client_tag': helm_client_tag,
             'node_problem_detector_tag': npd_tag,
             'auto_healing_enabled': auto_healing_enabled,
@@ -1258,6 +1254,8 @@ class AtomicK8sTemplateDefinitionTestCase(BaseK8sTemplateDefinitionTestCase):
             'containerd_tarball_sha256': containerd_tarball_sha256,
             'post_install_manifest_url': '',
             'metrics_scraper_tag': metrics_scraper_tag,
+            'master_lb_allowed_cidrs': master_lb_allowed_cidrs,
+            'fixed_subnet_cidr': '20.200.0.0/16',
         }}
         mock_get_params.assert_called_once_with(mock_context,
                                                 mock_cluster_template,
@@ -1521,6 +1519,49 @@ class AtomicK8sTemplateDefinitionTestCase(BaseK8sTemplateDefinitionTestCase):
             is_master=False
         )
 
+    def test_set_master_lb_allowed_cidrs(self):
+        definition = self.get_definition()
+        extra_params = {"master_lb_allowed_cidrs": "192.168.0.0/16"}
+        mock_cluster = mock.MagicMock()
+        mock_context = mock.MagicMock()
+        mock_cluster.labels = {}
+
+        definition._set_master_lb_allowed_cidrs(mock_context,
+                                                mock_cluster, extra_params)
+
+        self.assertEqual(extra_params["master_lb_allowed_cidrs"],
+                         "192.168.0.0/16,10.0.0.0/24")
+
+    def test_set_master_lb_allowed_cidrs_fixed_subnet_cidr(self):
+        definition = self.get_definition()
+        extra_params = {"master_lb_allowed_cidrs": "192.168.0.0/16"}
+        mock_cluster = mock.MagicMock()
+        mock_context = mock.MagicMock()
+        mock_cluster.labels = {"fixed_subnet_cidr": "100.0.0.0/24"}
+
+        definition._set_master_lb_allowed_cidrs(mock_context,
+                                                mock_cluster, extra_params)
+
+        self.assertEqual(extra_params["master_lb_allowed_cidrs"],
+                         "192.168.0.0/16,100.0.0.0/24")
+
+    @mock.patch('magnum.common.neutron.get_subnet')
+    def test_set_master_lb_allowed_cidrs_find_subnet_cidr(self,
+                                                          mock_get_subnet):
+        definition = self.get_definition()
+        extra_params = {"master_lb_allowed_cidrs": "192.168.0.0/16",
+                        "fixed_subnet": "fake_subnet_id"}
+        mock_cluster = mock.MagicMock()
+        mock_context = mock.MagicMock()
+        mock_cluster.labels = {}
+        mock_get_subnet.return_value = "172.24.0.0/16"
+
+        definition._set_master_lb_allowed_cidrs(mock_context,
+                                                mock_cluster, extra_params)
+
+        self.assertEqual(extra_params["master_lb_allowed_cidrs"],
+                         "192.168.0.0/16,172.24.0.0/16")
+
 
 class FedoraK8sIronicTemplateDefinitionTestCase(base.TestCase):
 
@@ -1669,6 +1710,7 @@ class AtomicSwarmModeTemplateDefinitionTestCase(base.TestCase):
         mock_stack.to_dict.return_value = {'outputs': outputs}
         mock_cluster_template = mock.MagicMock()
         mock_cluster_template.floating_ip_enabled = floating_ip_enabled
+        self.mock_cluster.floating_ip_enabled = floating_ip_enabled
 
         definition.update_outputs(mock_stack, mock_cluster_template,
                                   self.mock_cluster)
@@ -1745,6 +1787,13 @@ class AtomicSwarmModeTemplateDefinitionTestCase(base.TestCase):
         heat_param = swarm_def.get_heat_param(cluster_attr='uuid')
         self.assertEqual('cluster_uuid', heat_param)
 
+    def test_swarm_get_scale_params(self):
+        mock_context = mock.MagicMock()
+        swarm_def = swarm_v2_tdef.AtomicSwarmTemplateDefinition()
+        self.assertEqual(
+            swarm_def.get_scale_params(mock_context, self.mock_cluster, 7),
+            {'number_of_nodes': 7})
+
     def test_update_outputs(self):
         swarm_def = swarm_v2_tdef.AtomicSwarmTemplateDefinition()
 
@@ -2079,14 +2128,19 @@ class UbuntuMesosTemplateDefinitionTestCase(base.TestCase):
         mock_cluster.uuid = '5d12f6fd-a196-4bf0-ae4c-1f639a523a52'
 
         removal_nodes = ['node1', 'node2']
+        node_count = 7
         mock_scale_manager = mock.MagicMock()
         mock_scale_manager.get_removal_nodes.return_value = removal_nodes
 
         mesos_def = mesos_tdef.UbuntuMesosTemplateDefinition()
 
-        scale_params = mesos_def.get_scale_params(mock_context, mock_cluster,
-                                                  mock_scale_manager)
-        expected_scale_params = {'slaves_to_remove': ['node1', 'node2']}
+        scale_params = mesos_def.get_scale_params(
+            mock_context,
+            mock_cluster,
+            node_count,
+            mock_scale_manager)
+        expected_scale_params = {'slaves_to_remove': ['node1', 'node2'],
+                                 'number_of_slaves': 7}
         self.assertEqual(scale_params, expected_scale_params)
 
     def test_mesos_get_heat_param(self):
