@@ -355,7 +355,7 @@ class TestObject(test_base.TestCase, _TestObject):
 # For more information on object version testing, read
 # https://docs.openstack.org/magnum/latest/contributor/objects.html
 object_data = {
-    'Cluster': '1.18-9f0dfcc3e898eef2b9a09647b612adb6',
+    'Cluster': '1.22-39ae1aa9ed1e90ee05f67f64b5fce4bb',
     'ClusterTemplate': '1.19-3b0b2b3933d0955abf3ab40111744960',
     'Certificate': '1.1-1924dc077daa844f0f9076332ef96815',
     'MyObj': '1.0-34c4b1aadefd177b13f9a2f894cc23cd',
@@ -363,7 +363,8 @@ object_data = {
     'MagnumService': '1.0-2d397ec59b0046bd5ec35cd3e06efeca',
     'Stats': '1.0-73a1cd6e3c0294c932a66547faba216c',
     'Quota': '1.0-94e100aebfa88f7d8428e007f2049c18',
-    'Federation': '1.0-166da281432b083f0e4b851336e12e20'
+    'Federation': '1.0-166da281432b083f0e4b851336e12e20',
+    'NodeGroup': '1.0-8cb4544a28a49860d816158a7c3060b1'
 }
 
 
